function [gi, NvertDOF, NedgeDOF, NbubbleDOF] = enumerateDOFs(t,neig,pdeg,Nvert)
% Enumerate the global degrees of freedom. Take care about the boundary conditions.
% INPUT
%  t ... Ntri-by-3 triangles = each row contains three indices to v (== to vertices)
%  neig ... Ntri-by-3  neighbours across edges
%  pdeg ... Ntri-by-4 vector of polynomial degrees
%           pdeg(k,1) degree of the interior;  pdeg(k,2:4) degrees of the edges
%  Nvert ... number of vertices
% OUTPUT
%  gi ... Ntri-by-7  global indices to the stiffness matrix
%     if k is an index of an element then
%     gi(k,1:3) = indices of the three vertices
%     gi(k,4:6) = the first indices of the edge functions
%     gi(k,7)   = the first index of the bubble functions
% REMARK
%  Indices of vertex functinos:  1,...,NvertDOF
%  Indices of edge functions: NvertDOF+1,...,NvertDOF+NedgeDOF
%  Indices of bubble functions: NvertDOF+NedgeDOF+1,...,NvertDOF+NedgeDOF+NbubbleDOF

sft = [2 3 1];
Ntri = size(t,1);
%Nvert = zize(v,1);
gi = zeros(Ntri,7);

auxv = zeros(Nvert,1);

n = 0;

% Set -1 in auxv to the boundary vertices
% THIS GOES SUPERFLUOUSLY THROUGH ALL ELEMENTS - BUT HOW BETTER?
for k=1:Ntri
  for edge=1:3
    if (neig(k,edge) == -1)  % two Dirichlet boundary vertices
      v1 = sft(edge);
      v2 = sft(v1);
      auxv(t(k,v1)) = -1;
      auxv(t(k,v2)) = -1;
    end % if
  end % for edge
end % for k

% enumerate all  vertices
for k=1:Ntri
  for v=1:3
    if (auxv(t(k,v)) == 0)
      n=n+1;
      gi(k,v) = n;
      auxv(t(k,v)) = n;
    else
      gi(k,v) = auxv(t(k,v));
    end % if
  end % for edge
end % for k
NvertDOF = n;

% enumerate all edges
for k=1:Ntri
  for edge=1:3
    if (neig(k,edge) == -1)  % Dirichlet boundary edge
      gi(k,3+edge) = -1;
    else % interior edge
      if (pdeg(k,1+edge) >=2)
        if (gi(k,3+edge) == 0)  % not enumerated yet
          gi(k,3+edge) = n+1;
          % enumerate the neighbour
          neig1 = neig(k,edge);
          if (neig(neig1,1) == k) neigedge = 1;
          elseif (neig(neig1,2) == k) neigedge = 2;
          else neigedge = 3;
          end
          gi(neig1,3+neigedge) = n+1;
          % done
          n = n + pdeg(k,1+edge) - 1; % shift the index
        end
      else
        gi(k,3+edge) = -1; % no edge functions (pdeg too low)
      end % if
    end % if
  end % for edge
end % for k
NedgeDOF = n - NvertDOF;

% enumerate all bubbles
for k=1:Ntri
  if (pdeg(k,1) >= 3)
    gi(k,7) = n+1;
    n = n + (pdeg(k,1)-1)*(pdeg(k,1)-2)/2;
  else
    gi(k,7) = -1;  % no bubbles in this element (pdeg too low)
  end % if
end % for k
NbubbleDOF = n - NvertDOF - NedgeDOF;

% --- CHECK ---
for k=1:Ntri
  for i=1:7
    if (gi(k,i)==0)
      error('Check failed: some DOF was not enumerated');
    end
  end
end
% --- END CHECK ---

end % function
