function uhp = hpFEMsolver(v,t, polydeg)
% 2D hpFEM solver of equation -div( a grad u) + c u = f  with homogeneous Dirichlet cond.
% coefficients a and c are piecewise constant
% INPUT:
%  a,c,f ...  coefficients and right-hand side
%    are given in external m-files: a_coef.m, c_coef.m, f_coef.m
%    ( e.g. a=@(x)1; b=@(x)0; c=@(x)1; f=@(x)1+x^2 )
%    The values at the barycenters of elements only are considered.
%  v,t,neig ... defines the triangulations (geometry only)
%    v ... Nvert-by-2 coordinates of the vertices (Nvert = number of vertices)
%    t ... Ntri-by-3 triangles = each row contains three indices to v (== to vertices)
% %   neig ... Ntri-by-3  neighbours across edges [not used]
%  polydeg ... Ntri-by-1 - polynomial degrees of the elements (interior poly. degrees)
%              This can be a single number. Then each element has this degree.
%
% OUTPUT:
% - the hpFEM solution in uhp in an internal structure.
%   use evaluhp(uhp,x) to get a value at x
% uhp is a five element cell array:
% uhp{1} == c     the coefficients
% uhp{2} == gi    the global indices to the stiffness matrix (Ntri-by-7 => 3x vert, 3x edge, 1x inter)
% uhp{3} == v     the vertices of the triangulation
% uhp{4} == t     the triangles of the triangulation
% uhp{5} == pdeg  the polynomial degrees (Ntri-by-4 => interior and three edges)
%
% uhp(x)|_K = \sum_{i=1}^{p(k)+1} c(gi{k}(i))*HPHI{i}(xi),
% uhp(x)|_K =   \sum_{i=1}^3 c(gi(k,i))*lmb_i(x)
%             + \sum_{edge=1}^3 \sum_{i=0}^{pedge-2} c(gi(k,3+edge)+i)*lmb_1(x)^l*lmb_2(x)^m*lmb_3(x)^n
%             + \sum_{i=0}^{Nbub-1} c(gi(k,7)+i)*lmb_1(x)^l*lmb_2(x)^m*lmb_3(x)^n
% where k is the index of element K and
%   l,m,n  are given by Peanoshfun.m
%   lmb    barycentric coordinates
%
% TODO: Use standard Matlab data structures for the mesh (i.e, g,p,e,t).
%       It suffices to the transpose p and t.

% initial checks
Nvert = size(v,1);
Ntri = size(t,1);
if (Nvert < 3)
  error('The number of vertices in the mesh must be at least 3');
end
if (Ntri < 1)
  error('The number of triangles in the mesh must be at least 1');
end
if (size(polydeg) ~= [Ntri,1])
  error('polydeg must be a vector: number_of_elements-by-1');
end

% check of polynomial degrees
p_max = 10;  % maximal polynomial degree
if (max(polydeg) > p_max)
  error('Polynomial degrees must be at most %d', p_max);
end
if (min(polydeg) < 1)
  error('Polynomial degrees must be at least 1');
end

% definition of the shape functions on interval [-1,1]
%HPHI = shapefunctions();
%DHPHI = dshapefunctions();

blog('Find neighbours of triangles');
neig = findneighbours(t);
elog;

% run the solver
%fprintf('TotDOFs = %d\n', TotalDOFs(pdeg));
blog('Set polydegrees of edges, enumerate DOFs');
  pdeg = edgepdeg(neig,polydeg);  % minimum rule
  [gi, NvertDOF, NedgeDOF, NbubbleDOF] = enumerateDOFs(t,neig,pdeg,Nvert); % gi is Ntri-by-7
  NDOF = NvertDOF + NedgeDOF + NbubbleDOF;
elog;
  fprintf('         Numbers of DOFs: [vertex edge bubble  total] = [%d %d %d  %d]\n', ...
    NvertDOF, NedgeDOF, NbubbleDOF, NDOF);

%  blog('Precompute integrals');
%  precompint;
%  elog;

blog('Assemble stiffness matrix and load vector');
  [A,F] = assemblestiffload(v,t,pdeg,gi,NDOF);
elog;

blog('Solve linear system');
  c = A \ F;
  %full(A)
  %F
  %c
elog;

uhp{1} = c;
uhp{2} = gi;
uhp{3} = v;
uhp{4} = t;
uhp{5} = pdeg;
%  uhp{5} = HPHI;
%  uhp{6} = DHPHI;

%fprintf('|||uh||| = %g  enormfast = %g\n', sqrt(c'*A*c), sqrt(pi/8 - c'*A*c));

end % of function
