function [AK,FK] = locstiffload(k, v,t, pdeg)
% return the local stiffness matrix and load vector
% stiffness matrix = a_K * int_K grad(phi_i) dotprod grad(phi_j) + c_K * int_K phi_i * phi_j
% INPUT:
%  the external functions a_coef, c_coef, f_coef, f_order
%  k ... index of the element
%  v ... Nvert-by-2 coordinates of vertices in the triangulation
%  t ... Ntri-by-3 indices to the array v - triangles
%  pdeg ... Ntri-by-4 vector of polynomial degrees
%           pdeg(1) degree of the interior;  pdeg(2:4) degrees of the edges
% OUTPUT:
%  AK ... the local stiffness matrix NK-by-NK, where NK = sum(pdeg(2:4)) + (pdeg(1)-1)*(pdeg(1)-2)/2;
%  FK ... the local load vector NK-by-1
%
% TODO: (1) Input variables should be local: v...3-by-2, t...3-by-3, pdeg...3-by-4
%       (2) Check positive orientation of triangles

global hpFEM_intlambda

if isempty(hpFEM_intlambda)
  fprintf('\n');
  warning('Integrals are not precomputed (the global variable hpFEM_intlambda is empty). Precomputing integrals now.');
  precompint;
end % if

sft = [2 3 1];

% exponents of the shape functions
gvidx = t(k,:);
lmn = Peanoshfun(pdeg(k,1:4), gvidx);

% compute the products of the gradients of the barycentric coorinates
% == compute the cotangents of the angles in the triangle
% grad lmb_i dot grad lmb_j = dotprod(a_i,a_j) / det(W)^2,
% where a_i is the edge vector of the edge e_i, i.e., a_i = v_i2 - v_i1
% and det(W) = 2*area(T)
% t(k,:) ... indices of the vertices of the triangle k
vert = v(t(k,:),1:2); % == 3-by-2 matrix of the coordinates of the three vertices
W = [vert'; 1 1 1];
detW = det(W);

% ------ CHECK ----------
if (detW < 0)
  error('Triangle no. %d has negative orientation.',k);
end
% ------ END CHECK ------

detW21 = 1/(detW^2);
% the edge vectors = columns of ev
ev = zeros(2,3);
for i=1:3
  i1 = sft(i);
  i2 = sft(i1);
  ev(1:2,i) = (vert(i2,1:2) - vert(i1,1:2))';
end
% the matrix of the dot products of gradients of lambdas
AKp1 = detW21 * (ev' * ev);  % 3-by-3
%  AKp1 = zeros(3,3);
%  for i=1:3
%    for j=1:3
%      AKp1(i,j) = detW21 * (ev(i,:)' * ev(j,:));
%    end
%  end

% compute the values of coefficients in the barycenter
xbc = (vert' * [1; 1; 1]) / 3;
coefaK = a_coef(xbc(1),xbc(2));
coefcK = c_coef(xbc(1),xbc(2));
%  polynomiald degree of the RHS f (if f is not a polynomial use 20)
RHSorder = f_order(xbc(1),xbc(2));

% copute the local stiffness and mass matrices AK and MK:
%global hpFEM_intlambda  % emax+1 by emax+1 by emax+1;
NK = pdeg(k,2)+pdeg(k,3)+pdeg(k,4) + (pdeg(k,1)-1)*(pdeg(k,1)-2)/2;  % size of AK
AK = zeros(NK,NK);
FK = zeros(NK,1);
for i=1:NK
  l = lmn(i,1);
  m = lmn(i,2);
  n = lmn(i,3);
  for j=1:NK
    r = lmn(j,1);
    s = lmn(j,2);
    t = lmn(j,3);

    AKij = 0;
    e1 = l+r; e2=m+s; e3=n+t;
    %ee = [l+r, m+s, n+t];

    if (e1 >= 2 && e2 >= 0 && e3 >= 0)
    %if (ee >= [2 0 0])
      AKij = AKij + AKp1(1,1)*l*r*hpFEM_intlambda(e1-1,e2+1,e3+1);
    end
    if (e1 >= 1 && e2 >= 1 && e3 >= 0)
    %if (ee >= [1 1 0])
      AKij = AKij + AKp1(1,2)*l*s*hpFEM_intlambda(e1,e2,e3+1);
    end
    if (e1 >= 1 && e2 >= 0 && e3 >= 1)
    %if (ee >= [1 0 1])
      AKij = AKij + AKp1(1,3)*l*t*hpFEM_intlambda(e1,e2+1,e3);
    end

    if (e1 >= 1 && e2 >= 1 && e3 >= 0)
    %if (ee >= [1 1 0])
      AKij = AKij + AKp1(2,1)*m*r*hpFEM_intlambda(e1,e2,e3+1);
    end
    if (e1 >= 0 && e2 >= 2 && e3 >= 0)
    %if (ee >= [0 2 0])
      AKij = AKij + AKp1(2,2)*m*s*hpFEM_intlambda(e1+1,e2-1,e3+1);
    end
    if (e1 >= 0 && e2 >= 1 && e3 >= 1)
    %if (ee >= [0 1 1])
      AKij = AKij + AKp1(2,3)*m*t*hpFEM_intlambda(e1+1,e2,e3);
    end

    if (e1 >= 1 && e2 >= 0 && e3 >= 1)
    %if (ee >= [1 0 1])
      AKij = AKij + AKp1(3,1)*n*r*hpFEM_intlambda(e1,e2+1,e3);
    end
    if (e1 >= 0 && e2 >= 1 && e3 >= 1)
    %if (ee >= [0 1 1])
      AKij = AKij + AKp1(3,2)*n*s*hpFEM_intlambda(e1+1,e2,e3);
    end
    if (e1 >= 0 && e2 >= 0 && e3 >= 2)
    %if (ee >= [0 0 2])
      AKij = AKij + AKp1(3,3)*n*t*hpFEM_intlambda(e1+1,e2+1,e3-1);
    end

%      AKijold =  AKp1(1,1)*l*r*intlambda(l+r-2,m+s,n+t) ...   % *detW
%            + AKp1(1,2)*l*s*intlambda(l+r-1,m+s-1,n+t) ... % *detW
%            + AKp1(1,3)*l*t*intlambda(l+r-1,m+s,n+t-1) ... % *detW
%            + AKp1(2,1)*m*r*intlambda(l+r-1,m+s-1,n+t) ... % *detW
%            + AKp1(2,2)*m*s*intlambda(l+r,m+s-2,n+t) ...   % *detW
%            + AKp1(2,3)*m*t*intlambda(l+r,m+s-1,n+t-1) ... % *detW
%            + AKp1(3,1)*n*r*intlambda(l+r-1,m+s,n+t-1) ... % *detW
%            + AKp1(3,2)*n*s*intlambda(l+r,m+s-1,n+t-1) ... % *detW
%            + AKp1(3,3)*n*t*intlambda(l+r,m+s,n+t-2);      % *detW
%
%      if (abs(AKij - AKijold) > 1e-14) error('Check failed by %g', abs(AKij - AKijold)); end

    if (e1 >= 0 && e2 >= 0 && e3 >= 0)
      MKij = hpFEM_intlambda(e1+1,e2+1,e3+1);
    end
%      MKij = intlambda(l+r,m+s,n+t);

    AK(i,j) = coefaK * AKij + coefcK * MKij;

  end % for j

  % compute the contribution to the local load vector
  order = min([RHSorder + l+m+n, 20]);
  fval = trianglequad( @f_integrand, order); % *detW
  FK(i) = fval;

end % for i

AK = AK * detW;
FK = FK * 0.25*detW;

  function y = f_integrand(xi,eta)
  % Integrand of the RHS functional

    % lambda{1} = @(xi1,xi2)((-xi1-xi2)/2);
    % lambda{2} = @(xi1,xi2)((1+xi1)/2);
    % lambda{3} = @(xi1,xi2)((1+xi2)/2);
    %
    % xK = @(xi1,xi2)(lambda{1}(xi1,xi2)*V1 ...
    %  + lambda{2}(xi1,xi2)*V2 + lambda{3}(xi1,xi2)*V3);

    % x = xK(xi,eta);
    l1 = (-xi-eta)*0.5;
    l2 = (1+xi)*0.5;
    l3 = (1+eta)*0.5;
    x = l1*vert(1,1:2) + l2*vert(2,1:2) + l3*vert(3,1:2);
    y = f_coef(x(1),x(2)) * l1^l * l2^m * l3^n;
  end

  function val = intlambda(kk,ll,mm)
    if (kk<0 || ll<0 || mm<0)
      val = 0;
    else
      val = hpFEM_intlambda(kk+1,ll+1,mm+1);
    end
  end

end % function
