function val = trianglequad(f, order)
% Computes integral of f over reference triangle [-1,-1], [1,-1], [-1,1].
% It uses Gauss quadrature of order order.
% Remark:  Quadrature formulas for orders 11, 15, 16, 18, and 20 have points
%          outside the triangle!

persistent MaxOrder Quad2DPointNum Quad2DPointX Quad2DPointY Quad2DWeight
persistent outwarning

if (order == 11) || (order == 15) || (order == 16) || (order == 18) ...
   || (order == 20)
 if isempty(outwarning)
  warning('Using quadrature with points outside the triangle (order = %d)',...
    order);
  outwarning = 1;
 end
end

if isempty(MaxOrder)
  initquad();
end %if

if (order < 0) || (order > MaxOrder)
  error('order out of range');
end %if

N = Quad2DPointNum(order+1);
fval = zeros(N,1);
for k = 1 : N
  fval(k) = f(Quad2DPointX{order+1}(k), Quad2DPointY{order+1}(k));
end

% fprintf('w=%g  fval=%g\n', Quad2DWeight{order+1}, fval);

val = dot(Quad2DWeight{order+1}, fval);


function initquad()
  fprintf('Initializing quadrature points and weights...');
  MaxOrder = 20;
  Quad2DPointNum = zeros(MaxOrder+1,1);

  % 0. stupen
  Quad2DPointNum(0+1) = 1;
  Quad2DPointX{0+1} = zeros(Quad2DPointNum(0+1),1);
  Quad2DPointY{0+1} = zeros(Quad2DPointNum(0+1),1);
  Quad2DWeight{0+1} = zeros(Quad2DPointNum(0+1),1);

  Quad2DPointX{0+1}(0+1) = -1.0 / 3;
  Quad2DPointY{0+1}(0+1) = -1.0 / 3;
  Quad2DWeight{0+1}(0+1) = 2.0;


  % 1. stupen
  Quad2DPointNum(1+1) = 1;
  Quad2DPointX{1+1} = zeros(Quad2DPointNum(1+1),1);
  Quad2DPointY{1+1} = zeros(Quad2DPointNum(1+1),1);
  Quad2DWeight{1+1} = zeros(Quad2DPointNum(1+1),1);

  Quad2DPointX{1+1}(0+1) = -1.0 / 3;
  Quad2DPointY{1+1}(0+1) = -1.0 / 3;
  Quad2DWeight{1+1}(0+1) = 2.0;

  % 2. stupen
  Quad2DPointNum(2+1) = 3;
  Quad2DPointX{2+1} = zeros(Quad2DPointNum(2+1),1);
  Quad2DPointY{2+1} = zeros(Quad2DPointNum(2+1),1);
  Quad2DWeight{2+1} = zeros(Quad2DPointNum(2+1),1);

  Quad2DPointX{2+1}(0+1) = -2.0 / 3;
  Quad2DPointY{2+1}(0+1) = -2.0 / 3;
  Quad2DWeight{2+1}(0+1) = 2.0 / 3;

  Quad2DPointX{2+1}(1+1) = -2.0 / 3;
  Quad2DPointY{2+1}(1+1) = 1.0 / 3;
  Quad2DWeight{2+1}(1+1) = 2.0 / 3;

  Quad2DPointX{2+1}(2+1) = 1.0 / 3;
  Quad2DPointY{2+1}(2+1) = -2.0 / 3;
  Quad2DWeight{2+1}(2+1) = 2.0 / 3;

  % 3. stupen
  Quad2DPointNum(3+1) = 4;
  Quad2DPointX{3+1} = zeros(Quad2DPointNum(3+1),1);
  Quad2DPointY{3+1} = zeros(Quad2DPointNum(3+1),1);
  Quad2DWeight{3+1} = zeros(Quad2DPointNum(3+1),1);


  Quad2DPointX{3+1}(0+1) = -1.0 / 3;
  Quad2DPointY{3+1}(0+1) = -1.0 / 3;
  Quad2DWeight{3+1}(0+1) = -1.125;

  Quad2DPointX{3+1}(1+1) = -0.6;
  Quad2DPointY{3+1}(1+1) = -0.6;
  Quad2DWeight{3+1}(1+1) = 1.041666666666667;

  Quad2DPointX{3+1}(2+1) = -0.6;
  Quad2DPointY{3+1}(2+1) = 0.2;
  Quad2DWeight{3+1}(2+1) = 1.041666666666667;

  Quad2DPointX{3+1}(3+1) = 0.2;
  Quad2DPointY{3+1}(3+1) = -0.6;
  Quad2DWeight{3+1}(3+1) = 1.041666666666667;

  % 4. stupen
  Quad2DPointNum(4+1) = 6;
  Quad2DPointX{4+1} = zeros(Quad2DPointNum(4+1),1);
  Quad2DPointY{4+1} = zeros(Quad2DPointNum(4+1),1);
  Quad2DWeight{4+1} = zeros(Quad2DPointNum(4+1),1);

  Quad2DPointX{4+1}(0+1) = -0.108103018168070;
  Quad2DPointY{4+1}(0+1) = -0.108103018168070;
  Quad2DWeight{4+1}(0+1) = 0.446763179356022;

  Quad2DPointX{4+1}(1+1) = -0.108103018168070;
  Quad2DPointY{4+1}(1+1) = -0.783793963663860;
  Quad2DWeight{4+1}(1+1) = 0.446763179356022;

  Quad2DPointX{4+1}(2+1) = -0.783793963663860;
  Quad2DPointY{4+1}(2+1) = -0.108103018168070 ;
  Quad2DWeight{4+1}(2+1) = 0.446763179356022;

  Quad2DPointX{4+1}(3+1) = -0.816847572980458 ;
  Quad2DPointY{4+1}(3+1) = -0.816847572980458 ;
  Quad2DWeight{4+1}(3+1) = 0.219903487310644;

  Quad2DPointX{4+1}(4+1) = -0.816847572980458 ;
  Quad2DPointY{4+1}(4+1) = 0.633695145960918 ;
  Quad2DWeight{4+1}(4+1) = 0.219903487310644;

  Quad2DPointX{4+1}(5+1) = 0.633695145960918;
  Quad2DPointY{4+1}(5+1) = -0.816847572980458 ;
  Quad2DWeight{4+1}(5+1) = 0.219903487310644;

  % 5. stupen
  Quad2DPointNum(5+1) = 7;
  Quad2DPointX{5+1} = zeros(Quad2DPointNum(5+1),1);
  Quad2DPointY{5+1} = zeros(Quad2DPointNum(5+1),1);
  Quad2DWeight{5+1} = zeros(Quad2DPointNum(5+1),1);

  Quad2DPointX{5+1}(0+1) = -1.0/3;
  Quad2DPointY{5+1}(0+1) = -1.0/3;
  Quad2DWeight{5+1}(0+1) = 0.45;

  Quad2DPointX{5+1}(1+1) = -0.059715871789770;
  Quad2DPointY{5+1}(1+1) = -0.059715871789770;
  Quad2DWeight{5+1}(1+1) = 0.264788305577012;

  Quad2DPointX{5+1}(2+1) = -0.059715871789770;
  Quad2DPointY{5+1}(2+1) = -0.880568256420460;
  Quad2DWeight{5+1}(2+1) = 0.264788305577012;

  Quad2DPointX{5+1}(3+1) = -0.880568256420460;
  Quad2DPointY{5+1}(3+1) = -0.059715871789770;
  Quad2DWeight{5+1}(3+1) = 0.264788305577012;

  Quad2DPointX{5+1}(4+1) = -0.797426985353088;
  Quad2DPointY{5+1}(4+1) = -0.797426985353088;
  Quad2DWeight{5+1}(4+1) = 0.251878361089654;

  Quad2DPointX{5+1}(5+1) = -0.797426985353088;
  Quad2DPointY{5+1}(5+1) = 0.594853970706174;
  Quad2DWeight{5+1}(5+1) = 0.251878361089654;

  Quad2DPointX{5+1}(6+1) = 0.594853970706174;
  Quad2DPointY{5+1}(6+1) = -0.797426985353088;
  Quad2DWeight{5+1}(6+1) = 0.251878361089654;

  % 6. stupen
  Quad2DPointNum(6+1) = 12;
  Quad2DPointX{6+1} = zeros(Quad2DPointNum(6+1),1);
  Quad2DPointY{6+1} = zeros(Quad2DPointNum(6+1),1);
  Quad2DWeight{6+1} = zeros(Quad2DPointNum(6+1),1);

  Quad2DPointX{6+1}(0+1) = -0.501426509658180;
  Quad2DPointY{6+1}(0+1) = -0.501426509658180;
  Quad2DWeight{6+1}(0+1) = 0.233572551452758;

  Quad2DPointX{6+1}(1+1) = -0.501426509658180;
  Quad2DPointY{6+1}(1+1) = 0.002853019316358;
  Quad2DWeight{6+1}(1+1) = 0.233572551452758;

  Quad2DPointX{6+1}(2+1) = 0.002853019316358;
  Quad2DPointY{6+1}(2+1) = -0.501426509658180;
  Quad2DWeight{6+1}(2+1) = 0.233572551452758;

  Quad2DPointX{6+1}(3+1) = -0.873821971016996 ;
  Quad2DPointY{6+1}(3+1) = -0.873821971016996;
  Quad2DWeight{6+1}(3+1) = 0.101689812740414;

  Quad2DPointX{6+1}(4+1) = -0.873821971016996;
  Quad2DPointY{6+1}(4+1) = 0.747643942033992;
  Quad2DWeight{6+1}(4+1) = 0.101689812740414;

  Quad2DPointX{6+1}(5+1) = 0.747643942033992;
  Quad2DPointY{6+1}(5+1) = -0.873821971016996;
  Quad2DWeight{6+1}(5+1) = 0.101689812740414;

  Quad2DPointX{6+1}(6+1) = -0.379295097932432;
  Quad2DPointY{6+1}(6+1) = 0.273004998242798;
  Quad2DWeight{6+1}(6+1) = 0.165702151236748;

  Quad2DPointX{6+1}(7+1) = 0.273004998242798 ;
  Quad2DPointY{6+1}(7+1) = -0.893709900310366;
  Quad2DWeight{6+1}(7+1) = 0.165702151236748;

  Quad2DPointX{6+1}(8+1) = -0.893709900310366;
  Quad2DPointY{6+1}(8+1) = -0.379295097932432;
  Quad2DWeight{6+1}(8+1) = 0.165702151236748;

  Quad2DPointX{6+1}(9+1) = -0.379295097932432;
  Quad2DPointY{6+1}(9+1) = -0.893709900310366;
  Quad2DWeight{6+1}(9+1) = 0.165702151236748;

  Quad2DPointX{6+1}(10+1) = 0.273004998242798;
  Quad2DPointY{6+1}(10+1) = -0.379295097932432;
  Quad2DWeight{6+1}(10+1) = 0.165702151236748;

  Quad2DPointX{6+1}(11+1) = -0.893709900310366;
  Quad2DPointY{6+1}(11+1) = 0.273004998242798;
  Quad2DWeight{6+1}(11+1) = 0.165702151236748;

  % 7. stupen
  Quad2DPointNum(7+1) = 13;
  Quad2DPointX{7+1} = zeros(Quad2DPointNum(7+1),1);
  Quad2DPointY{7+1} = zeros(Quad2DPointNum(7+1),1);
  Quad2DWeight{7+1} = zeros(Quad2DPointNum(7+1),1);

  Quad2DPointX{7+1}(0+1) = -1.0/3;
  Quad2DPointY{7+1}(0+1) = -1.0/3;
  Quad2DWeight{7+1}(0+1) = -0.299140088935364;

  Quad2DPointX{7+1}(1+1) = -0.479308067841920;
  Quad2DPointY{7+1}(1+1) = -0.479308067841920;
  Quad2DWeight{7+1}(1+1) = 0.351230514866416;

  Quad2DPointX{7+1}(2+1) = -0.479308067841920;
  Quad2DPointY{7+1}(2+1) = -0.041383864316160;
  Quad2DWeight{7+1}(2+1) = 0.351230514866416;

  Quad2DPointX{7+1}(3+1) = -0.041383864316160;
  Quad2DPointY{7+1}(3+1) = -0.479308067841920;
  Quad2DWeight{7+1}(3+1) = 0.351230514866416;

  Quad2DPointX{7+1}(4+1) = -0.869739794195568;
  Quad2DPointY{7+1}(4+1) = -0.869739794195568;
  Quad2DWeight{7+1}(4+1) = 0.106694471217676;

  Quad2DPointX{7+1}(5+1) = -0.869739794195568;
  Quad2DPointY{7+1}(5+1) = 0.739479588391136;
  Quad2DWeight{7+1}(5+1) = 0.106694471217676;

  Quad2DPointX{7+1}(6+1) = 0.739479588391136;
  Quad2DPointY{7+1}(6+1) = -0.869739794195568;
  Quad2DWeight{7+1}(6+1) = 0.106694471217676;

  Quad2DPointX{7+1}(7+1) = -0.374269007990252;
  Quad2DPointY{7+1}(7+1) = 0.276888377139620;
  Quad2DWeight{7+1}(7+1) = 0.154227521780514;

  Quad2DPointX{7+1}(8+1) = 0.276888377139620;
  Quad2DPointY{7+1}(8+1) = -0.902619369149368;
  Quad2DWeight{7+1}(8+1) = 0.154227521780514;

  Quad2DPointX{7+1}(9+1) = -0.902619369149368;
  Quad2DPointY{7+1}(9+1) = -0.374269007990252;
  Quad2DWeight{7+1}(9+1) = 0.154227521780514;

  Quad2DPointX{7+1}(10+1) = -0.374269007990252;
  Quad2DPointY{7+1}(10+1) = -0.902619369149368;
  Quad2DWeight{7+1}(10+1) = 0.154227521780514;

  Quad2DPointX{7+1}(11+1) = 0.276888377139620;
  Quad2DPointY{7+1}(11+1) = -0.374269007990252;
  Quad2DWeight{7+1}(11+1) = 0.154227521780514;

  Quad2DPointX{7+1}(12+1) = -0.902619369149368;
  Quad2DPointY{7+1}(12+1) = 0.276888377139620;
  Quad2DWeight{7+1}(12+1) = 0.154227521780514;

  % 8. stupen
  Quad2DPointNum(8+1) = 16;
  Quad2DPointX{8+1} = zeros(Quad2DPointNum(8+1),1);
  Quad2DPointY{8+1} = zeros(Quad2DPointNum(8+1),1);
  Quad2DWeight{8+1} = zeros(Quad2DPointNum(8+1),1);

  Quad2DPointX{8+1}(0+1) = -1.0/3;
  Quad2DPointY{8+1}(0+1) = -1.0/3;
  Quad2DWeight{8+1}(0+1) = 0.288631215355574;

  Quad2DPointX{8+1}(1+1) = -0.081414823414554;
  Quad2DPointY{8+1}(1+1) = -0.081414823414554;
  Quad2DWeight{8+1}(1+1) = 0.190183268534570;

  Quad2DPointX{8+1}(2+1) = -0.081414823414554;
  Quad2DPointY{8+1}(2+1) = -0.837170353170892;
  Quad2DWeight{8+1}(2+1) = 0.190183268534570;

  Quad2DPointX{8+1}(3+1) = -0.837170353170892;
  Quad2DPointY{8+1}(3+1) = -0.081414823414554;
  Quad2DWeight{8+1}(3+1) = 0.190183268534570;

  Quad2DPointX{8+1}(4+1) = -0.658861384496480;
  Quad2DPointY{8+1}(4+1) = -0.658861384496480;
  Quad2DWeight{8+1}(4+1) = 0.206434741069436;

  Quad2DPointX{8+1}(5+1) = -0.658861384496480;
  Quad2DPointY{8+1}(5+1) = 0.317722768992960;
  Quad2DWeight{8+1}(5+1) = 0.206434741069436;

  Quad2DPointX{8+1}(6+1) = 0.317722768992960;
  Quad2DPointY{8+1}(6+1) = -0.658861384496480;
  Quad2DWeight{8+1}(6+1) = 0.206434741069436;

  Quad2DPointX{8+1}(7+1) = -0.898905543365938;
  Quad2DPointY{8+1}(7+1) = -0.898905543365938;
  Quad2DWeight{8+1}(7+1) = 0.064916995246396;

  Quad2DPointX{8+1}(8+1) = -0.898905543365938;
  Quad2DPointY{8+1}(8+1) = 0.797811086731876;
  Quad2DWeight{8+1}(8+1) = 0.064916995246395;

  Quad2DPointX{8+1}(9+1) = 0.797811086731876;
  Quad2DPointY{8+1}(9+1) = -0.898905543365938;
  Quad2DWeight{8+1}(9+1) = 0.064916995246396;

  Quad2DPointX{8+1}(10+1) = -0.473774340730724;
  Quad2DPointY{8+1}(10+1) = 0.456984785910808;
  Quad2DWeight{8+1}(10+1) = 0.054460628348870;

  Quad2DPointX{8+1}(11+1) = 0.456984785910808;
  Quad2DPointY{8+1}(11+1) = -0.983210445180084;
  Quad2DWeight{8+1}(11+1) = 0.054460628348870;

  Quad2DPointX{8+1}(12+1) = -0.983210445180084;
  Quad2DPointY{8+1}(12+1) = -0.473774340730724;
  Quad2DWeight{8+1}(12+1) = 0.054460628348870;

  Quad2DPointX{8+1}(13+1) = -0.473774340730724;
  Quad2DPointY{8+1}(13+1) = -0.983210445180084;
  Quad2DWeight{8+1}(13+1) = 0.054460628348870;

  Quad2DPointX{8+1}(14+1) = 0.456984785910808;
  Quad2DPointY{8+1}(14+1) = -0.473774340730724;
  Quad2DWeight{8+1}(14+1) = 0.054460628348870;

  Quad2DPointX{8+1}(15+1) = -0.983210445180084;
  Quad2DPointY{8+1}(15+1) = 0.456984785910808;
  Quad2DWeight{8+1}(15+1) = 0.054460628348870;

  % 9. stupen
  Quad2DPointNum(9+1) = 19;
  Quad2DPointX{9+1} = zeros(Quad2DPointNum(9+1),1);
  Quad2DPointY{9+1} = zeros(Quad2DPointNum(9+1),1);
  Quad2DWeight{9+1} = zeros(Quad2DPointNum(9+1),1);

  Quad2DPointX{9+1}(0+1) = -1.0/3;
  Quad2DPointY{9+1}(0+1) = -1.0/3;
  Quad2DWeight{9+1}(0+1) = 0.194271592565598;

  Quad2DPointX{9+1}(1+1) = -0.020634961602524;
  Quad2DPointY{9+1}(1+1) = -0.020634961602524;
  Quad2DWeight{9+1}(1+1) = 0.062669400454278;

  Quad2DPointX{9+1}(2+1) = -0.020634961602524;
  Quad2DPointY{9+1}(2+1) = -0.958730076794950;
  Quad2DWeight{9+1}(2+1) = 0.062669400454278;

  Quad2DPointX{9+1}(3+1) = -0.958730076794950;
  Quad2DPointY{9+1}(3+1) = -0.020634961602524;
  Quad2DWeight{9+1}(3+1) = 0.062669400454278;

  Quad2DPointX{9+1}(4+1) = -0.125820817014126;
  Quad2DPointY{9+1}(4+1) = -0.125820817014126;
  Quad2DWeight{9+1}(4+1) = 0.155655082009548;

  Quad2DPointX{9+1}(5+1) = -0.125820817014126;
  Quad2DPointY{9+1}(5+1) = -0.748358365971746;
  Quad2DWeight{9+1}(5+1) = 0.155655082009548;

  Quad2DPointX{9+1}(6+1) = -0.748358365971746;
  Quad2DPointY{9+1}(6+1) = -0.125820817014126;
  Quad2DWeight{9+1}(6+1) = 0.155655082009548;

  Quad2DPointX{9+1}(7+1) = -0.623592928761934;
  Quad2DPointY{9+1}(7+1) = -0.623592928761934;
  Quad2DWeight{9+1}(7+1) = 0.159295477854420;

  Quad2DPointX{9+1}(8+1) = -0.623592928761934;
  Quad2DPointY{9+1}(8+1) = 0.247185857523870;
  Quad2DWeight{9+1}(8+1) = 0.159295477854420;

  Quad2DPointX{9+1}(9+1) = 0.247185857523870;
  Quad2DPointY{9+1}(9+1) = -0.623592928761934;
  Quad2DWeight{9+1}(9+1) = 0.159295477854420;

  Quad2DPointX{9+1}(10+1) = -0.910540973211094;
  Quad2DPointY{9+1}(10+1) = -0.910540973211094;
  Quad2DWeight{9+1}(10+1) = 0.051155351317396;

  Quad2DPointX{9+1}(11+1) = -0.910540973211094;
  Quad2DPointY{9+1}(11+1) = 0.821081946422190;
  Quad2DWeight{9+1}(11+1) = 0.051155351317396;

  Quad2DPointX{9+1}(12+1) = 0.821081946422190;
  Quad2DPointY{9+1}(12+1) = -0.910540973211094;
  Quad2DWeight{9+1}(12+1) = 0.051155351317396;

  Quad2DPointX{9+1}(13+1) = -0.556074021678468;
  Quad2DPointY{9+1}(13+1) = 0.482397197568996;
  Quad2DWeight{9+1}(13+1) = 0.086567078754578;

  Quad2DPointX{9+1}(14+1) = 0.482397197568996;
  Quad2DPointY{9+1}(14+1) = -0.926323175890528;
  Quad2DWeight{9+1}(14+1) = 0.086567078754578;

  Quad2DPointX{9+1}(15+1) = -0.926323175890528;
  Quad2DPointY{9+1}(15+1) = -0.556074021678468;
  Quad2DWeight{9+1}(15+1) = 0.086567078754578;

  Quad2DPointX{9+1}(16+1) = -0.556074021678468;
  Quad2DPointY{9+1}(16+1) = -0.926323175890528;
  Quad2DWeight{9+1}(16+1) = 0.086567078754578;

  Quad2DPointX{9+1}(17+1) = 0.482397197568996;
  Quad2DPointY{9+1}(17+1) = -0.556074021678468;
  Quad2DWeight{9+1}(17+1) = 0.086567078754578;

  Quad2DPointX{9+1}(18+1) = -0.926323175890528;
  Quad2DPointY{9+1}(18+1) = 0.482397197568996;
  Quad2DWeight{9+1}(18+1) = 0.086567078754578;

  % 10. stupen
  Quad2DPointNum(10+1) = 25;
  Quad2DPointX{10+1} = zeros(Quad2DPointNum(10+1),1);
  Quad2DPointY{10+1} = zeros(Quad2DPointNum(10+1),1);
  Quad2DWeight{10+1} = zeros(Quad2DPointNum(10+1),1);

  Quad2DPointX{10+1}(0+1) = -1.0/3;
  Quad2DPointY{10+1}(0+1) = -1.0/3;
  Quad2DWeight{10+1}(0+1) = 0.181635980765508;

  Quad2DPointX{10+1}(1+1) = -0.028844733232686;
  Quad2DPointY{10+1}(1+1) = -0.028844733232686;
  Quad2DWeight{10+1}(1+1) = 0.073451915512934;

  Quad2DPointX{10+1}(2+1) = -0.028844733232686;
  Quad2DPointY{10+1}(2+1) = -0.942310533534630;
  Quad2DWeight{10+1}(2+1) = 0.073451915512934;

  Quad2DPointX{10+1}(3+1) = -0.942310533534630;
  Quad2DPointY{10+1}(3+1) = -0.028844733232686;
  Quad2DWeight{10+1}(3+1) = 0.073451915512934;

  Quad2DPointX{10+1}(4+1) = -0.781036849029926 ;
  Quad2DPointY{10+1}(4+1) = -0.781036849029926;
  Quad2DWeight{10+1}(4+1) = 0.090642118871056;

  Quad2DPointX{10+1}(5+1) = -0.781036849029926;
  Quad2DPointY{10+1}(5+1) = 0.562073698059852;
  Quad2DWeight{10+1}(5+1) = 0.090642118871056;

  Quad2DPointX{10+1}(6+1) = 0.562073698059852;
  Quad2DPointY{10+1}(6+1) = -0.781036849029926;
  Quad2DWeight{10+1}(6+1) = 0.090642118871056;

  Quad2DPointX{10+1}(7+1) = -0.384120322471758;
  Quad2DPointY{10+1}(7+1) = 0.100705883641998;
  Quad2DWeight{10+1}(7+1) = 0.145515833690840;

  Quad2DPointX{10+1}(8+1) = 0.100705883641998;
  Quad2DPointY{10+1}(8+1) = -0.716585561170240;
  Quad2DWeight{10+1}(8+1) = 0.145515833690840;

  Quad2DPointX{10+1}(9+1) = -0.716585561170240;
  Quad2DPointY{10+1}(9+1) = -0.384120322471758;
  Quad2DWeight{10+1}(9+1) = 0.145515833690840;

  Quad2DPointX{10+1}(10+1) = -0.384120322471758;
  Quad2DPointY{10+1}(10+1) = -0.716585561170240;
  Quad2DWeight{10+1}(10+1) = 0.145515833690840;

  Quad2DPointX{10+1}(11+1) = 0.100705883641998;
  Quad2DPointY{10+1}(11+1) = -0.384120322471758;
  Quad2DWeight{10+1}(11+1) = 0.145515833690840;

  Quad2DPointX{10+1}(12+1) = -0.716585561170240;
  Quad2DPointY{10+1}(12+1) = 0.100705883641998;
  Quad2DWeight{10+1}(12+1) = 0.145515833690840;

  Quad2DPointX{10+1}(13+1) = -0.506654878720194;
  Quad2DPointY{10+1}(13+1) = 0.456647809194822;
  Quad2DWeight{10+1}(13+1) = 0.056654485062114;

  Quad2DPointX{10+1}(14+1) = 0.456647809194822;
  Quad2DPointY{10+1}(14+1) = -0.949992930474628;
  Quad2DWeight{10+1}(14+1) = 0.056654485062114;

  Quad2DPointX{10+1}(15+1) = -0.949992930474628;
  Quad2DPointY{10+1}(15+1) = -0.506654878720194;
  Quad2DWeight{10+1}(15+1) = 0.056654485062114;

  Quad2DPointX{10+1}(16+1) = -0.506654878720194;
  Quad2DPointY{10+1}(16+1) = -0.949992930474628;
  Quad2DWeight{10+1}(16+1) = 0.056654485062114;

  Quad2DPointX{10+1}(17+1) = 0.456647809194822;
  Quad2DPointY{10+1}(17+1) = -0.506654878720194;
  Quad2DWeight{10+1}(17+1) = 0.056654485062114;

  Quad2DPointX{10+1}(18+1) = -0.949992930474628;
  Quad2DPointY{10+1}(18+1) = 0.456647809194822;
  Quad2DWeight{10+1}(18+1) = 0.056654485062114;

  Quad2DPointX{10+1}(19+1) = -0.866393497975600;
  Quad2DPointY{10+1}(19+1) = 0.847311867175000;
  Quad2DWeight{10+1}(19+1) = 0.018843333927466;

  Quad2DPointX{10+1}(20+1) = 0.847311867175000;
  Quad2DPointY{10+1}(20+1) = -0.980918369199402;
  Quad2DWeight{10+1}(20+1) = 0.018843333927466;

  Quad2DPointX{10+1}(21+1) = -0.980918369199402;
  Quad2DPointY{10+1}(21+1) = -0.866393497975600;
  Quad2DWeight{10+1}(21+1) = 0.018843333927466;

  Quad2DPointX{10+1}(22+1) = -0.866393497975600;
  Quad2DPointY{10+1}(22+1) = -0.980918369199402;
  Quad2DWeight{10+1}(22+1) = 0.018843333927466;

  Quad2DPointX{10+1}(23+1) = 0.847311867175000;
  Quad2DPointY{10+1}(23+1) = -0.866393497975600;
  Quad2DWeight{10+1}(23+1) = 0.018843333927466;

  Quad2DPointX{10+1}(24+1) = -0.980918369199402;
  Quad2DPointY{10+1}(24+1) = 0.847311867175000;
  Quad2DWeight{10+1}(24+1) = 0.018843333927466;

  % 11. stupen
  Quad2DPointNum(11+1) = 27;
  Quad2DPointX{11+1} = zeros(Quad2DPointNum(11+1),1);
  Quad2DPointY{11+1} = zeros(Quad2DPointNum(11+1),1);
  Quad2DWeight{11+1} = zeros(Quad2DPointNum(11+1),1);

  Quad2DPointX{11+1}(0+1) = 0.069222096541516;
  Quad2DPointY{11+1}(0+1) = 0.069222096541516;
  Quad2DWeight{11+1}(0+1) = 0.001854012657922;

  Quad2DPointX{11+1}(1+1) = 0.069222096541516;
  Quad2DPointY{11+1}(1+1) = -1.138444193083034;
  Quad2DWeight{11+1}(1+1) = 0.001854012657922;

  Quad2DPointX{11+1}(2+1) = -1.138444193083034;
  Quad2DPointY{11+1}(2+1) = 0.069222096541516;
  Quad2DWeight{11+1}(2+1) = 0.001854012657922;

  Quad2DPointX{11+1}(3+1) = -0.202061394068290;
  Quad2DPointY{11+1}(3+1) = -0.202061394068290;
  Quad2DWeight{11+1}(3+1) = 0.154299069829626;

  Quad2DPointX{11+1}(4+1) = -0.202061394068290;
  Quad2DPointY{11+1}(4+1) = -0.595877211863420;
  Quad2DWeight{11+1}(4+1) = 0.154299069829626;

  Quad2DPointX{11+1}(5+1) = -0.595877211863420;
  Quad2DPointY{11+1}(5+1) = -0.202061394068290;
  Quad2DWeight{11+1}(5+1) = 0.154299069829626;

  Quad2DPointX{11+1}(6+1) = -0.593380199137436;
  Quad2DPointY{11+1}(6+1) = -0.593380199137436;
  Quad2DWeight{11+1}(6+1) = 0.118645954761548;

  Quad2DPointX{11+1}(7+1) = -0.593380199137436;
  Quad2DPointY{11+1}(7+1) = 0.186760398274870;
  Quad2DWeight{11+1}(7+1) = 0.118645954761548;

  Quad2DPointX{11+1}(8+1) = 0.186760398274870;
  Quad2DPointY{11+1}(8+1) = -0.593380199137436;
  Quad2DWeight{11+1}(8+1) = 0.118645954761548;

  Quad2DPointX{11+1}(9+1) = -0.761298175434838;
  Quad2DPointY{11+1}(9+1) = -0.761298175434838;
  Quad2DWeight{11+1}(9+1) = 0.072369081006836;

  Quad2DPointX{11+1}(10+1) = -0.761298175434838;
  Quad2DPointY{11+1}(10+1) = 0.522596350869674;
  Quad2DWeight{11+1}(10+1) = 0.072369081006836;

  Quad2DPointX{11+1}(11+1) = 0.522596350869674;
  Quad2DPointY{11+1}(11+1) = -0.761298175434838;
  Quad2DWeight{11+1}(11+1) = 0.072369081006836;

  Quad2DPointX{11+1}(12+1) = -0.935270103777448;
  Quad2DPointY{11+1}(12+1) = -0.935270103777448;
  Quad2DWeight{11+1}(12+1) = 0.027319462005356;

  Quad2DPointX{11+1}(13+1) = -0.935270103777448;
  Quad2DPointY{11+1}(13+1) = 0.870540207554896;
  Quad2DWeight{11+1}(13+1) = 0.027319462005356;

  Quad2DPointX{11+1}(14+1) = 0.870540207554896;
  Quad2DPointY{11+1}(14+1) = -0.935270103777448;
  Quad2DWeight{11+1}(14+1) = 0.027319462005356;

  Quad2DPointX{11+1}(15+1) = -0.286758703477414;
  Quad2DPointY{11+1}(15+1) = 0.186402426856426;
  Quad2DWeight{11+1}(15+1) = 0.104674223924408;

  Quad2DPointX{11+1}(16+1) = 0.186402426856426;
  Quad2DPointY{11+1}(16+1) = -0.899643723379010;
  Quad2DWeight{11+1}(16+1) = 0.104674223924408;

  Quad2DPointX{11+1}(17+1) = -0.899643723379010;
  Quad2DPointY{11+1}(17+1) = -0.286758703477414;
  Quad2DWeight{11+1}(17+1) = 0.104674223924408;

  Quad2DPointX{11+1}(18+1) = -0.286758703477414;
  Quad2DPointY{11+1}(18+1) = -0.899643723379010;
  Quad2DWeight{11+1}(18+1) = 0.104674223924408;

  Quad2DPointX{11+1}(19+1) = 0.186402426856426;
  Quad2DPointY{11+1}(19+1) = -0.286758703477414;
  Quad2DWeight{11+1}(19+1) = 0.104674223924408;

  Quad2DPointX{11+1}(20+1) = -0.899643723379010;
  Quad2DPointY{11+1}(20+1) = 0.186402426856426;
  Quad2DWeight{11+1}(20+1) = 0.104674223924408;

  Quad2DPointX{11+1}(21+1) = -0.657022039391916;
  Quad2DPointY{11+1}(21+1) = 0.614978006319584;
  Quad2DWeight{11+1}(21+1) = 0.041415319278282;

  Quad2DPointX{11+1}(22+1) = 0.614978006319584;
  Quad2DPointY{11+1}(22+1) = -0.957955966927668;
  Quad2DWeight{11+1}(22+1) = 0.041415319278282;

  Quad2DPointX{11+1}(23+1) = -0.957955966927668;
  Quad2DPointY{11+1}(23+1) = -0.657022039391916;
  Quad2DWeight{11+1}(23+1) = 0.041415319278282;

  Quad2DPointX{11+1}(24+1) = -0.657022039391916;
  Quad2DPointY{11+1}(24+1) = -0.957955966927668;
  Quad2DWeight{11+1}(24+1) = 0.041415319278282;

  Quad2DPointX{11+1}(25+1) = 0.614978006319584;
  Quad2DPointY{11+1}(25+1) = -0.657022039391916;
  Quad2DWeight{11+1}(25+1) = 0.041415319278282;

  Quad2DPointX{11+1}(26+1) = -0.957955966927668;
  Quad2DPointY{11+1}(26+1) = 0.614978006319584;
  Quad2DWeight{11+1}(26+1) = 0.041415319278282;

  % 12. stupen
  Quad2DPointNum(12+1) = 33;
  Quad2DPointX{12+1} = zeros(Quad2DPointNum(12+1),1);
  Quad2DPointY{12+1} = zeros(Quad2DPointNum(12+1),1);
  Quad2DWeight{12+1} = zeros(Quad2DPointNum(12+1),1);

  Quad2DPointX{12+1}(0+1) = -0.023565220452390;
  Quad2DPointY{12+1}(0+1) = -0.023565220452390;
  Quad2DWeight{12+1}(0+1) = 0.051462132880910;

  Quad2DPointX{12+1}(1+1) = -0.023565220452390;
  Quad2DPointY{12+1}(1+1) = -0.952869559095220;
  Quad2DWeight{12+1}(1+1) = 0.051462132880910;

  Quad2DPointX{12+1}(2+1) = -0.952869559095220;
  Quad2DPointY{12+1}(2+1) = -0.023565220452390;
  Quad2DWeight{12+1}(2+1) = 0.051462132880910;

  Quad2DPointX{12+1}(3+1) = -0.120551215411080;
  Quad2DPointY{12+1}(3+1) = -0.120551215411080;
  Quad2DWeight{12+1}(3+1) = 0.087385089076076;

  Quad2DPointX{12+1}(4+1) = -0.120551215411080;
  Quad2DPointY{12+1}(4+1) = -0.758897569177842;
  Quad2DWeight{12+1}(4+1) = 0.087385089076076;

  Quad2DPointX{12+1}(5+1) = -0.758897569177842;
  Quad2DPointY{12+1}(5+1) = -0.120551215411080;
  Quad2DWeight{12+1}(5+1) = 0.087385089076076;

  Quad2DPointX{12+1}(6+1) = -0.457579229975768;
  Quad2DPointY{12+1}(6+1) = -0.457579229975768;
  Quad2DWeight{12+1}(6+1) = 0.125716448435770;

  Quad2DPointX{12+1}(7+1) = -0.457579229975768;
  Quad2DPointY{12+1}(7+1) = -0.084841540048464;
  Quad2DWeight{12+1}(7+1) = 0.125716448435770;

  Quad2DPointX{12+1}(8+1) = -0.084841540048464;
  Quad2DPointY{12+1}(8+1) = -0.457579229975768;
  Quad2DWeight{12+1}(8+1) = 0.125716448435770;

  Quad2DPointX{12+1}(9+1) = -0.744847708916828;
  Quad2DPointY{12+1}(9+1) = -0.744847708916828;
  Quad2DWeight{12+1}(9+1) = 0.069592225861418;

  Quad2DPointX{12+1}(10+1) = -0.744847708916828;
  Quad2DPointY{12+1}(10+1) = 0.489695417833656;
  Quad2DWeight{12+1}(10+1) = 0.069592225861418;

  Quad2DPointX{12+1}(11+1) = 0.489695417833656;
  Quad2DPointY{12+1}(11+1) = -0.744847708916828;
  Quad2DWeight{12+1}(11+1) = 0.069592225861418;

  Quad2DPointX{12+1}(12+1) = -0.957365299093580;
  Quad2DPointY{12+1}(12+1) = -0.957365299093580;
  Quad2DWeight{12+1}(12+1) = 0.012332522103118;

  Quad2DPointX{12+1}(13+1) = -0.957365299093580;
  Quad2DPointY{12+1}(13+1) = 0.914730598187158;
  Quad2DWeight{12+1}(13+1) = 0.012332522103118;

  Quad2DPointX{12+1}(14+1) = 0.914730598187158;
  Quad2DPointY{12+1}(14+1) = -0.957365299093580;
  Quad2DWeight{12+1}(14+1) = 0.012332522103118;

  Quad2DPointX{12+1}(15+1) = -0.448573460628972;
  Quad2DPointY{12+1}(15+1) = 0.217886471559576;
  Quad2DWeight{12+1}(15+1) = 0.080743115532762;

  Quad2DPointX{12+1}(16+1) = 0.217886471559576;
  Quad2DPointY{12+1}(16+1) = -0.769313010930604;
  Quad2DWeight{12+1}(16+1) = 0.080743115532762;

  Quad2DPointX{12+1}(17+1) = -0.769313010930604;
  Quad2DPointY{12+1}(17+1) = -0.448573460628972;
  Quad2DWeight{12+1}(17+1) = 0.080743115532762;

  Quad2DPointX{12+1}(18+1) = -0.448573460628972;
  Quad2DPointY{12+1}(18+1) = -0.769313010930604;
  Quad2DWeight{12+1}(18+1) = 0.080743115532762;

  Quad2DPointX{12+1}(19+1) = 0.217886471559576;
  Quad2DPointY{12+1}(19+1) = -0.448573460628972;
  Quad2DWeight{12+1}(19+1) = 0.080743115532762;

  Quad2DPointX{12+1}(20+1) = -0.769313010930604;
  Quad2DPointY{12+1}(20+1) = 0.217886471559576;
  Quad2DWeight{12+1}(20+1) = 0.080743115532762;

  Quad2DPointX{12+1}(21+1) = -0.437348838020120;
  Quad2DPointY{12+1}(21+1) = 0.391672173575606;
  Quad2DWeight{12+1}(21+1) = 0.044713546404606;

  Quad2DPointX{12+1}(22+1) = 0.391672173575606;
  Quad2DPointY{12+1}(22+1) = -0.954323335555486;
  Quad2DWeight{12+1}(22+1) = 0.044713546404606;

  Quad2DPointX{12+1}(23+1) = -0.954323335555486;
  Quad2DPointY{12+1}(23+1) = -0.437348838020120;
  Quad2DWeight{12+1}(23+1) = 0.044713546404606;

  Quad2DPointX{12+1}(24+1) = -0.437348838020120;
  Quad2DPointY{12+1}(24+1) = -0.954323335555486;
  Quad2DWeight{12+1}(24+1) = 0.044713546404606;

  Quad2DPointX{12+1}(25+1) = 0.391672173575606;
  Quad2DPointY{12+1}(25+1) = -0.437348838020120;
  Quad2DWeight{12+1}(25+1) = 0.044713546404606;

  Quad2DPointX{12+1}(26+1) = -0.954323335555486;
  Quad2DPointY{12+1}(26+1) = 0.391672173575606;
  Quad2DWeight{12+1}(26+1) = 0.044713546404606;

  Quad2DPointX{12+1}(27+1) = -0.767496168184806;
  Quad2DPointY{12+1}(27+1) = 0.716028067088146;
  Quad2DWeight{12+1}(27+1) = 0.034632462217318;

  Quad2DPointX{12+1}(28+1) = 0.716028067088146;
  Quad2DPointY{12+1}(28+1) = -0.948531898903340;
  Quad2DWeight{12+1}(28+1) = 0.034632462217318;

  Quad2DPointX{12+1}(29+1) = -0.948531898903340;
  Quad2DPointY{12+1}(29+1) = -0.767496168184806;
  Quad2DWeight{12+1}(29+1) = 0.034632462217318;

  Quad2DPointX{12+1}(30+1) = -0.767496168184806;
  Quad2DPointY{12+1}(30+1) = -0.948531898903340;
  Quad2DWeight{12+1}(30+1) = 0.034632462217318;

  Quad2DPointX{12+1}(31+1) = 0.716028067088146;
  Quad2DPointY{12+1}(31+1) = -0.767496168184806;
  Quad2DWeight{12+1}(31+1) = 0.034632462217318;

  Quad2DPointX{12+1}(32+1) = -0.948531898903340;
  Quad2DPointY{12+1}(32+1) = 0.716028067088146;
  Quad2DWeight{12+1}(32+1) = 0.034632462217318;

  % 13. stupen
  Quad2DPointNum(13+1) = 37;
  Quad2DPointX{13+1} = zeros(Quad2DPointNum(13+1),1);
  Quad2DPointY{13+1} = zeros(Quad2DPointNum(13+1),1);
  Quad2DWeight{13+1} = zeros(Quad2DPointNum(13+1),1);

  Quad2DPointX{13+1}(0+1) = -0.333333333333333;
  Quad2DPointY{13+1}(0+1) = -0.333333333333333;
  Quad2DWeight{13+1}(0+1) = 0.105041846801604;

  Quad2DPointX{13+1}(1+1) = -0.009903630120590;
  Quad2DPointY{13+1}(1+1) = -0.009903630120590;
  Quad2DWeight{13+1}(1+1) = 0.022560290418660;

  Quad2DPointX{13+1}(2+1) = -0.009903630120590;
  Quad2DPointY{13+1}(2+1) = -0.980192739758818;
  Quad2DWeight{13+1}(2+1) = 0.022560290418660;

  Quad2DPointX{13+1}(3+1) = -0.980192739758818;
  Quad2DPointY{13+1}(3+1) = -0.009903630120590;
  Quad2DWeight{13+1}(3+1) = 0.022560290418660;

  Quad2DPointX{13+1}(4+1) = -0.062566729780852;
  Quad2DPointY{13+1}(4+1) = -0.062566729780852;
  Quad2DWeight{13+1}(4+1) = 0.062847036724908;

  Quad2DPointX{13+1}(5+1) = -0.062566729780852;
  Quad2DPointY{13+1}(5+1) = -0.874866540438296;
  Quad2DWeight{13+1}(5+1) = 0.062847036724908;

  Quad2DPointX{13+1}(6+1) = -0.874866540438296;
  Quad2DPointY{13+1}(6+1) = -0.062566729780852;
  Quad2DWeight{13+1}(6+1) = 0.062847036724908;

  Quad2DPointX{13+1}(7+1) = -0.170957326397446;
  Quad2DPointY{13+1}(7+1) = -0.170957326397446;
  Quad2DWeight{13+1}(7+1) = 0.094145005008388;

  Quad2DPointX{13+1}(8+1) = -0.170957326397446;
  Quad2DPointY{13+1}(8+1) = -0.658085347205106;
  Quad2DWeight{13+1}(8+1) = 0.094145005008388;

  Quad2DPointX{13+1}(9+1) = -0.658085347205106;
  Quad2DPointY{13+1}(9+1) = -0.170957326397446;
  Quad2DWeight{13+1}(9+1) = 0.094145005008388;

  Quad2DPointX{13+1}(10+1) = -0.541200855914338;
  Quad2DPointY{13+1}(10+1) = -0.541200855914338;
  Quad2DWeight{13+1}(10+1) = 0.094727173072710;

  Quad2DPointX{13+1}(11+1) = -0.541200855914338;
  Quad2DPointY{13+1}(11+1) = 0.082401711828674;
  Quad2DWeight{13+1}(11+1) = 0.094727173072710;

  Quad2DPointX{13+1}(12+1) = 0.082401711828674;
  Quad2DPointY{13+1}(12+1) = -0.541200855914338;
  Quad2DWeight{13+1}(12+1) = 0.094727173072710;

  Quad2DPointX{13+1}(13+1) = -0.771151009607340;
  Quad2DPointY{13+1}(13+1) = -0.771151009607340;
  Quad2DWeight{13+1}(13+1) = 0.062335058091588;

  Quad2DPointX{13+1}(14+1) = -0.771151009607340;
  Quad2DPointY{13+1}(14+1) = 0.542302019214680;
  Quad2DWeight{13+1}(14+1) = 0.062335058091588;

  Quad2DPointX{13+1}(15+1) = 0.542302019214680;
  Quad2DPointY{13+1}(15+1) = -0.771151009607340;
  Quad2DWeight{13+1}(15+1) = 0.062335058091588;

  Quad2DPointX{13+1}(16+1) = -0.950377217273082;
  Quad2DPointY{13+1}(16+1) = -0.950377217273082;
  Quad2DWeight{13+1}(16+1) = 0.015951542930148;

  Quad2DPointX{13+1}(17+1) = -0.950377217273082;
  Quad2DPointY{13+1}(17+1) = 0.900754434546164;
  Quad2DWeight{13+1}(17+1) = 0.015951542930148;

  Quad2DPointX{13+1}(18+1) = 0.900754434546164;
  Quad2DPointY{13+1}(18+1) = -0.950377217273082;
  Quad2DWeight{13+1}(18+1) = 0.015951542930148;

  Quad2DPointX{13+1}(19+1) = -0.462410005882478;
  Quad2DPointY{13+1}(19+1) = 0.272702349123320;
  Quad2DWeight{13+1}(19+1) = 0.073696805457464;

  Quad2DPointX{13+1}(20+1) = 0.272702349123320;
  Quad2DPointY{13+1}(20+1) = -0.810292343240842;
  Quad2DWeight{13+1}(20+1) = 0.073696805457464;

  Quad2DPointX{13+1}(21+1) = -0.810292343240842;
  Quad2DPointY{13+1}(21+1) = -0.462410005882478;
  Quad2DWeight{13+1}(21+1) = 0.073696805457464;

  Quad2DPointX{13+1}(22+1) = -0.462410005882478;
  Quad2DPointY{13+1}(22+1) = -0.810292343240842;
  Quad2DWeight{13+1}(22+1) = 0.073696805457464;

  Quad2DPointX{13+1}(23+1) = 0.272702349123320;
  Quad2DPointY{13+1}(23+1) = -0.462410005882478;
  Quad2DWeight{13+1}(23+1) = 0.073696805457464;

  Quad2DPointX{13+1}(24+1) = -0.810292343240842;
  Quad2DPointY{13+1}(24+1) = 0.272702349123320;
  Quad2DWeight{13+1}(24+1) = 0.073696805457464;

  Quad2DPointX{13+1}(25+1) = -0.416539866531424;
  Quad2DPointY{13+1}(25+1) = 0.380338319973810;
  Quad2DWeight{13+1}(25+1) = 0.034802926607644;

  Quad2DPointX{13+1}(26+1) = 0.380338319973810;
  Quad2DPointY{13+1}(26+1) = -0.963798453442386;
  Quad2DWeight{13+1}(26+1) = 0.034802926607644;

  Quad2DPointX{13+1}(27+1) = -0.963798453442386;
  Quad2DPointY{13+1}(27+1) = -0.416539866531424;
  Quad2DWeight{13+1}(27+1) = 0.034802926607644;

  Quad2DPointX{13+1}(28+1) = -0.416539866531424;
  Quad2DPointY{13+1}(28+1) = -0.963798453442386;
  Quad2DWeight{13+1}(28+1) = 0.034802926607644;

  Quad2DPointX{13+1}(29+1) = 0.380338319973810;
  Quad2DPointY{13+1}(29+1) = -0.416539866531424;
  Quad2DWeight{13+1}(29+1) = 0.034802926607644;

  Quad2DPointX{13+1}(30+1) = -0.963798453442386;
  Quad2DPointY{13+1}(30+1) = 0.380338319973810;
  Quad2DWeight{13+1}(30+1) = 0.034802926607644;

  Quad2DPointX{13+1}(31+1) = -0.747285229016662;
  Quad2DPointY{13+1}(31+1) = 0.702819075668482;
  Quad2DWeight{13+1}(31+1) = 0.031043573678090;

  Quad2DPointX{13+1}(32+1) = 0.702819075668482;
  Quad2DPointY{13+1}(32+1) = -0.955533846651820;
  Quad2DWeight{13+1}(32+1) = 0.031043573678090;

  Quad2DPointX{13+1}(33+1) = -0.955533846651820;
  Quad2DPointY{13+1}(33+1) = -0.747285229016662;
  Quad2DWeight{13+1}(33+1) = 0.031043573678090;

  Quad2DPointX{13+1}(34+1) = -0.747285229016662;
  Quad2DPointY{13+1}(34+1) = -0.955533846651820;
  Quad2DWeight{13+1}(34+1) = 0.031043573678090;

  Quad2DPointX{13+1}(35+1) = 0.702819075668482;
  Quad2DPointY{13+1}(35+1) = -0.747285229016662;
  Quad2DWeight{13+1}(35+1) = 0.031043573678090;

  Quad2DPointX{13+1}(36+1) = -0.955533846651820;
  Quad2DPointY{13+1}(36+1) = 0.702819075668482;
  Quad2DWeight{13+1}(36+1) = 0.031043573678090;

  % 14. stupen
  Quad2DPointNum(14+1) = 42;
  Quad2DPointX{14+1} = zeros(Quad2DPointNum(14+1),1);
  Quad2DPointY{14+1} = zeros(Quad2DPointNum(14+1),1);
  Quad2DWeight{14+1} = zeros(Quad2DPointNum(14+1),1);

  Quad2DPointX{14+1}(0+1) = -0.022072179275642;
  Quad2DPointY{14+1}(0+1) = -0.022072179275642;
  Quad2DWeight{14+1}(0+1) = 0.043767162738858;

  Quad2DPointX{14+1}(1+1) = -0.022072179275642;
  Quad2DPointY{14+1}(1+1) = -0.955855641448714;
  Quad2DWeight{14+1}(1+1) = 0.043767162738858;

  Quad2DPointX{14+1}(2+1) = -0.955855641448714;
  Quad2DPointY{14+1}(2+1) = -0.022072179275642;
  Quad2DWeight{14+1}(2+1) = 0.043767162738858;

  Quad2DPointX{14+1}(3+1) = -0.164710561319092;
  Quad2DPointY{14+1}(3+1) = -0.164710561319092;
  Quad2DWeight{14+1}(3+1) = 0.065576707088250;

  Quad2DPointX{14+1}(4+1) = -0.164710561319092;
  Quad2DPointY{14+1}(4+1) = -0.670578877361816;
  Quad2DWeight{14+1}(4+1) = 0.065576707088250;

  Quad2DPointX{14+1}(5+1) = -0.670578877361816;
  Quad2DPointY{14+1}(5+1) = -0.164710561319092;
  Quad2DWeight{14+1}(5+1) = 0.065576707088250;

  Quad2DPointX{14+1}(6+1) = -0.453044943382322;
  Quad2DPointY{14+1}(6+1) = -0.453044943382322;
  Quad2DWeight{14+1}(6+1) = 0.103548209014584;

  Quad2DPointX{14+1}(7+1) = -0.453044943382322;
  Quad2DPointY{14+1}(7+1) = -0.093910113235354;
  Quad2DWeight{14+1}(7+1) = 0.103548209014584;

  Quad2DPointX{14+1}(8+1) = -0.093910113235354;
  Quad2DPointY{14+1}(8+1) = -0.453044943382322;
  Quad2DWeight{14+1}(8+1) = 0.103548209014584;

  Quad2DPointX{14+1}(9+1) = -0.645588935174914;
  Quad2DPointY{14+1}(9+1) = -0.645588935174914;
  Quad2DWeight{14+1}(9+1) = 0.084325177473986;

  Quad2DPointX{14+1}(10+1) = -0.645588935174914;
  Quad2DPointY{14+1}(10+1) = 0.291177870349826;
  Quad2DWeight{14+1}(10+1) = 0.084325177473986;

  Quad2DPointX{14+1}(11+1) = 0.291177870349826;
  Quad2DPointY{14+1}(11+1) = -0.645588935174914;
  Quad2DWeight{14+1}(11+1) = 0.084325177473986;

  Quad2DPointX{14+1}(12+1) = -0.876400233818254;
  Quad2DPointY{14+1}(12+1) = -0.876400233818254;
  Quad2DWeight{14+1}(12+1) = 0.028867399339554;

  Quad2DPointX{14+1}(13+1) = -0.876400233818254;
  Quad2DPointY{14+1}(13+1) = 0.752800467636510;
  Quad2DWeight{14+1}(13+1) = 0.028867399339554;

  Quad2DPointX{14+1}(14+1) = 0.752800467636510;
  Quad2DPointY{14+1}(14+1) = -0.876400233818254;
  Quad2DWeight{14+1}(14+1) = 0.028867399339554;

  Quad2DPointX{14+1}(15+1) = -0.961218077502598;
  Quad2DPointY{14+1}(15+1) = -0.961218077502598;
  Quad2DWeight{14+1}(15+1) = 0.009846807204800;

  Quad2DPointX{14+1}(16+1) = -0.961218077502598;
  Quad2DPointY{14+1}(16+1) = 0.922436155005196;
  Quad2DWeight{14+1}(16+1) = 0.009846807204800;

  Quad2DPointX{14+1}(17+1) = 0.922436155005196;
  Quad2DPointY{14+1}(17+1) = -0.961218077502598;
  Quad2DWeight{14+1}(17+1) = 0.009846807204800;

  Quad2DPointX{14+1}(18+1) = -0.655466624357288;
  Quad2DPointY{14+1}(18+1) = 0.541217109549992;
  Quad2DWeight{14+1}(18+1) = 0.049331506425128;

  Quad2DPointX{14+1}(19+1) = 0.541217109549992;
  Quad2DPointY{14+1}(19+1) = -0.885750485192704;
  Quad2DWeight{14+1}(19+1) = 0.049331506425128;

  Quad2DPointX{14+1}(20+1) = -0.885750485192704;
  Quad2DPointY{14+1}(20+1) = -0.655466624357288;
  Quad2DWeight{14+1}(20+1) = 0.049331506425128;

  Quad2DPointX{14+1}(21+1) = -0.655466624357288;
  Quad2DPointY{14+1}(21+1) = -0.885750485192704;
  Quad2DWeight{14+1}(21+1) = 0.049331506425128;

  Quad2DPointX{14+1}(22+1) = 0.541217109549992;
  Quad2DPointY{14+1}(22+1) = -0.655466624357288;
  Quad2DWeight{14+1}(22+1) = 0.049331506425128;

  Quad2DPointX{14+1}(23+1) = -0.885750485192704;
  Quad2DPointY{14+1}(23+1) = 0.541217109549992;
  Quad2DWeight{14+1}(23+1) = 0.049331506425128;

  Quad2DPointX{14+1}(24+1) = -0.326277080407310;
  Quad2DPointY{14+1}(24+1) = 0.140444581693366;
  Quad2DWeight{14+1}(24+1) = 0.077143021574122;

  Quad2DPointX{14+1}(25+1) = 0.140444581693366;
  Quad2DPointY{14+1}(25+1) = -0.814167501286056;
  Quad2DWeight{14+1}(25+1) = 0.077143021574122;

  Quad2DPointX{14+1}(26+1) = -0.814167501286056;
  Quad2DPointY{14+1}(26+1) = -0.326277080407310;
  Quad2DWeight{14+1}(26+1) = 0.077143021574122;

  Quad2DPointX{14+1}(27+1) = -0.326277080407310;
  Quad2DPointY{14+1}(27+1) = -0.814167501286056;
  Quad2DWeight{14+1}(27+1) = 0.077143021574122;

  Quad2DPointX{14+1}(28+1) = 0.140444581693366;
  Quad2DPointY{14+1}(28+1) = -0.326277080407310;
  Quad2DWeight{14+1}(28+1) = 0.077143021574122;

  Quad2DPointX{14+1}(29+1) = -0.814167501286056;
  Quad2DPointY{14+1}(29+1) = 0.140444581693366;
  Quad2DWeight{14+1}(29+1) = 0.077143021574122;

  Quad2DPointX{14+1}(30+1) = -0.403254235727484;
  Quad2DPointY{14+1}(30+1) = 0.373960335616176;
  Quad2DWeight{14+1}(30+1) = 0.028872616227068;

  Quad2DPointX{14+1}(31+1) = 0.373960335616176;
  Quad2DPointY{14+1}(31+1) = -0.970706099888692;
  Quad2DWeight{14+1}(31+1) = 0.028872616227068;

  Quad2DPointX{14+1}(32+1) = -0.970706099888692;
  Quad2DPointY{14+1}(32+1) = -0.403254235727484;
  Quad2DWeight{14+1}(32+1) = 0.028872616227068;

  Quad2DPointX{14+1}(33+1) = -0.403254235727484;
  Quad2DPointY{14+1}(33+1) = -0.970706099888692;
  Quad2DWeight{14+1}(33+1) = 0.028872616227068;

  Quad2DPointX{14+1}(34+1) = 0.373960335616176;
  Quad2DPointY{14+1}(34+1) = -0.403254235727484;
  Quad2DWeight{14+1}(34+1) = 0.028872616227068;

  Quad2DPointX{14+1}(35+1) = -0.970706099888692;
  Quad2DPointY{14+1}(35+1) = 0.373960335616176;
  Quad2DWeight{14+1}(35+1) = 0.028872616227068;

  Quad2DPointX{14+1}(36+1) = -0.762051004606086;
  Quad2DPointY{14+1}(36+1) = 0.759514342740342;
  Quad2DWeight{14+1}(36+1) = 0.010020457677002;

  Quad2DPointX{14+1}(37+1) = 0.759514342740342;
  Quad2DPointY{14+1}(37+1) = -0.997463338134256;
  Quad2DWeight{14+1}(37+1) = 0.010020457677002;

  Quad2DPointX{14+1}(38+1) = -0.997463338134256;
  Quad2DPointY{14+1}(38+1) = -0.762051004606086;
  Quad2DWeight{14+1}(38+1) = 0.010020457677002;

  Quad2DPointX{14+1}(39+1) = -0.762051004606086;
  Quad2DPointY{14+1}(39+1) = -0.997463338134256;
  Quad2DWeight{14+1}(39+1) = 0.010020457677002;

  Quad2DPointX{14+1}(40+1) = 0.759514342740342;
  Quad2DPointY{14+1}(40+1) = -0.762051004606086;
  Quad2DWeight{14+1}(40+1) = 0.010020457677002;

  Quad2DPointX{14+1}(41+1) = -0.997463338134256;
  Quad2DPointY{14+1}(41+1) = 0.759514342740342;
  Quad2DWeight{14+1}(41+1) = 0.010020457677002;

  % 15. stupen
  Quad2DPointNum(15+1) = 48;
  Quad2DPointX{15+1} = zeros(Quad2DPointNum(15+1),1);
  Quad2DPointY{15+1} = zeros(Quad2DPointNum(15+1),1);
  Quad2DWeight{15+1} = zeros(Quad2DPointNum(15+1),1);

  Quad2DPointX{15+1}(0+1) = 0.013945833716486;
  Quad2DPointY{15+1}(0+1) = 0.013945833716486;
  Quad2DWeight{15+1}(0+1) = 0.003833751285698;

  Quad2DPointX{15+1}(1+1) = 0.013945833716486;
  Quad2DPointY{15+1}(1+1) = -1.027891667432972;
  Quad2DWeight{15+1}(1+1) = 0.003833751285698;

  Quad2DPointX{15+1}(2+1) = -1.027891667432972;
  Quad2DPointY{15+1}(2+1) = 0.013945833716486;
  Quad2DWeight{15+1}(2+1) = 0.003833751285698;

  Quad2DPointX{15+1}(3+1) = -0.137187291433954;
  Quad2DPointY{15+1}(3+1) = -0.137187291433954;
  Quad2DWeight{15+1}(3+1) = 0.088498054542290;

  Quad2DPointX{15+1}(4+1) = -0.137187291433954;
  Quad2DPointY{15+1}(4+1) = -0.725625417132090;
  Quad2DWeight{15+1}(4+1) = 0.088498054542290;

  Quad2DPointX{15+1}(5+1) = -0.725625417132090;
  Quad2DPointY{15+1}(5+1) = -0.137187291433954;
  Quad2DWeight{15+1}(5+1) = 0.088498054542290;

  Quad2DPointX{15+1}(6+1) = -0.444612710305712;
  Quad2DPointY{15+1}(6+1) = -0.444612710305712;
  Quad2DWeight{15+1}(6+1) = 0.102373097437704;

  Quad2DPointX{15+1}(7+1) = -0.444612710305712;
  Quad2DPointY{15+1}(7+1) = -0.110774579388578;
  Quad2DWeight{15+1}(7+1) = 0.102373097437704;

  Quad2DPointX{15+1}(8+1) = -0.110774579388578;
  Quad2DPointY{15+1}(8+1) = -0.444612710305712;
  Quad2DWeight{15+1}(8+1) = 0.102373097437704;

  Quad2DPointX{15+1}(9+1) = -0.747070217917492;
  Quad2DPointY{15+1}(9+1) = -0.747070217917492;
  Quad2DWeight{15+1}(9+1) = 0.047375471741376;

  Quad2DPointX{15+1}(10+1) = -0.747070217917492;
  Quad2DPointY{15+1}(10+1) = 0.494140435834984;
  Quad2DWeight{15+1}(10+1) = 0.047375471741376;

  Quad2DPointX{15+1}(11+1) = 0.494140435834984;
  Quad2DPointY{15+1}(11+1) = -0.747070217917492;
  Quad2DWeight{15+1}(11+1) = 0.047375471741376;

  Quad2DPointX{15+1}(12+1) = -0.858383228050628;
  Quad2DPointY{15+1}(12+1) = -0.858383228050628;
  Quad2DWeight{15+1}(12+1) = 0.026579551380042;

  Quad2DPointX{15+1}(13+1) = -0.858383228050628;
  Quad2DPointY{15+1}(13+1) = 0.716766456101256;
  Quad2DWeight{15+1}(13+1) = 0.026579551380042;

  Quad2DPointX{15+1}(14+1) = 0.716766456101256;
  Quad2DPointY{15+1}(14+1) = -0.858383228050628;
  Quad2DWeight{15+1}(14+1) = 0.026579551380042;

  Quad2DPointX{15+1}(15+1) = -0.962069659517854;
  Quad2DPointY{15+1}(15+1) = -0.962069659517854;
  Quad2DWeight{15+1}(15+1) = 0.009497833216384;

  Quad2DPointX{15+1}(16+1) = -0.962069659517854;
  Quad2DPointY{15+1}(16+1) = 0.924139319035706;
  Quad2DWeight{15+1}(16+1) = 0.009497833216384;

  Quad2DPointX{15+1}(17+1) = 0.924139319035706;
  Quad2DPointY{15+1}(17+1) = -0.962069659517854;
  Quad2DWeight{15+1}(17+1) = 0.009497833216384;

  Quad2DPointX{15+1}(18+1) = -0.477377257719826;
  Quad2DPointY{15+1}(18+1) = 0.209908933786582;
  Quad2DWeight{15+1}(18+1) = 0.077100145199186;

  Quad2DPointX{15+1}(19+1) = 0.209908933786582;
  Quad2DPointY{15+1}(19+1) = -0.732531676066758;
  Quad2DWeight{15+1}(19+1) = 0.077100145199186;

  Quad2DPointX{15+1}(20+1) = -0.732531676066758;
  Quad2DPointY{15+1}(20+1) = -0.477377257719826;
  Quad2DWeight{15+1}(20+1) = 0.077100145199186;

  Quad2DPointX{15+1}(21+1) = -0.477377257719826;
  Quad2DPointY{15+1}(21+1) = -0.732531676066758;
  Quad2DWeight{15+1}(21+1) = 0.077100145199186;

  Quad2DPointX{15+1}(22+1) = 0.209908933786582;
  Quad2DPointY{15+1}(22+1) = -0.477377257719826;
  Quad2DWeight{15+1}(22+1) = 0.077100145199186;

  Quad2DPointX{15+1}(23+1) = -0.732531676066758;
  Quad2DPointY{15+1}(23+1) = 0.209908933786582;
  Quad2DWeight{15+1}(23+1) = 0.077100145199186;

  Quad2DPointX{15+1}(24+1) = -0.223906465819462;
  Quad2DPointY{15+1}(24+1) = 0.151173111025628;
  Quad2DWeight{15+1}(24+1) = 0.054431628641248;

  Quad2DPointX{15+1}(25+1) = 0.151173111025628;
  Quad2DPointY{15+1}(25+1) = -0.927266645206166;
  Quad2DWeight{15+1}(25+1) = 0.054431628641248;

  Quad2DPointX{15+1}(26+1) = -0.927266645206166;
  Quad2DPointY{15+1}(26+1) = -0.223906465819462;
  Quad2DWeight{15+1}(26+1) = 0.054431628641248;

  Quad2DPointX{15+1}(27+1) = -0.223906465819462;
  Quad2DPointY{15+1}(27+1) = -0.927266645206166;
  Quad2DWeight{15+1}(27+1) = 0.054431628641248;

  Quad2DPointX{15+1}(28+1) = 0.151173111025628;
  Quad2DPointY{15+1}(28+1) = -0.223906465819462;
  Quad2DWeight{15+1}(28+1) = 0.054431628641248;

  Quad2DPointX{15+1}(29+1) = -0.927266645206166;
  Quad2DPointY{15+1}(29+1) = 0.151173111025628;
  Quad2DWeight{15+1}(29+1) = 0.054431628641248;

  Quad2DPointX{15+1}(30+1) = -0.428575559900168;
  Quad2DPointY{15+1}(30+1) = 0.448925326153310;
  Quad2DWeight{15+1}(30+1) = 0.004364154733594;

  Quad2DPointX{15+1}(31+1) = 0.448925326153310;
  Quad2DPointY{15+1}(31+1) = -1.020349766253142;
  Quad2DWeight{15+1}(31+1) = 0.004364154733594;

  Quad2DPointX{15+1}(32+1) = -1.020349766253142;
  Quad2DPointY{15+1}(32+1) = -0.428575559900168;
  Quad2DWeight{15+1}(32+1) = 0.004364154733594;

  Quad2DPointX{15+1}(33+1) = -0.428575559900168;
  Quad2DPointY{15+1}(33+1) = -1.020349766253142;
  Quad2DWeight{15+1}(33+1) = 0.004364154733594;

  Quad2DPointX{15+1}(34+1) = 0.448925326153310;
  Quad2DPointY{15+1}(34+1) = -0.428575559900168;
  Quad2DWeight{15+1}(34+1) = 0.004364154733594;

  Quad2DPointX{15+1}(35+1) = -1.020349766253142;
  Quad2DPointY{15+1}(35+1) = 0.448925326153310;
  Quad2DWeight{15+1}(35+1) = 0.004364154733594;

  Quad2DPointX{15+1}(36+1) = -0.568800671855432;
  Quad2DPointY{15+1}(36+1) = 0.495112932103676;
  Quad2DWeight{15+1}(36+1) = 0.043010639695462;

  Quad2DPointX{15+1}(37+1) = 0.495112932103676;
  Quad2DPointY{15+1}(37+1) = -0.926312260248244;
  Quad2DWeight{15+1}(37+1) = 0.043010639695462;

  Quad2DPointX{15+1}(38+1) = -0.926312260248244;
  Quad2DPointY{15+1}(38+1) = -0.568800671855432;
  Quad2DWeight{15+1}(38+1) = 0.043010639695462;

  Quad2DPointX{15+1}(39+1) = -0.568800671855432;
  Quad2DPointY{15+1}(39+1) = -0.926312260248244;
  Quad2DWeight{15+1}(39+1) = 0.043010639695462;

  Quad2DPointX{15+1}(40+1) = 0.495112932103676;
  Quad2DPointY{15+1}(40+1) = -0.568800671855432;
  Quad2DWeight{15+1}(40+1) = 0.043010639695462;

  Quad2DPointX{15+1}(41+1) = -0.926312260248244;
  Quad2DPointY{15+1}(41+1) = 0.495112932103676;
  Quad2DWeight{15+1}(41+1) = 0.043010639695462;

  Quad2DPointX{15+1}(42+1) = -0.792848766847228;
  Quad2DPointY{15+1}(42+1) = 0.767929148184832;
  Quad2DWeight{15+1}(42+1) = 0.015347885262098;

  Quad2DPointX{15+1}(43+1) = 0.767929148184832;
  Quad2DPointY{15+1}(43+1) = -0.975080381337602;
  Quad2DWeight{15+1}(43+1) = 0.015347885262098;

  Quad2DPointX{15+1}(44+1) = -0.975080381337602;
  Quad2DPointY{15+1}(44+1) = -0.792848766847228;
  Quad2DWeight{15+1}(44+1) = 0.015347885262098;

  Quad2DPointX{15+1}(45+1) = -0.792848766847228;
  Quad2DPointY{15+1}(45+1) = -0.975080381337602;
  Quad2DWeight{15+1}(45+1) = 0.015347885262098;

  Quad2DPointX{15+1}(46+1) = 0.767929148184832;
  Quad2DPointY{15+1}(46+1) = -0.792848766847228;
  Quad2DWeight{15+1}(46+1) = 0.015347885262098;

  Quad2DPointX{15+1}(47+1) = -0.975080381337602;
  Quad2DPointY{15+1}(47+1) = 0.767929148184832;
  Quad2DWeight{15+1}(47+1) = 0.015347885262098;

  % 16. stupen
  Quad2DPointNum(16+1) = 52;
  Quad2DPointX{16+1} = zeros(Quad2DPointNum(16+1),1);
  Quad2DPointY{16+1} = zeros(Quad2DPointNum(16+1),1);
  Quad2DWeight{16+1} = zeros(Quad2DPointNum(16+1),1);

  Quad2DPointX{16+1}(0+1) = -0.333333333333333;
  Quad2DPointY{16+1}(0+1) = -0.333333333333333;
  Quad2DWeight{16+1}(0+1) = 0.093751394855284;

  Quad2DPointX{16+1}(1+1) = -0.005238916103124;
  Quad2DPointY{16+1}(1+1) = -0.005238916103124;
  Quad2DWeight{16+1}(1+1) = 0.012811757157170;

  Quad2DPointX{16+1}(2+1) = -0.005238916103124;
  Quad2DPointY{16+1}(2+1) = -0.989522167793754;
  Quad2DWeight{16+1}(2+1) = 0.012811757157170;

  Quad2DPointX{16+1}(3+1) = -0.989522167793754;
  Quad2DPointY{16+1}(3+1) = -0.005238916103124;
  Quad2DWeight{16+1}(3+1) = 0.012811757157170;

  Quad2DPointX{16+1}(4+1) = -0.173061122901296;
  Quad2DPointY{16+1}(4+1) = -0.173061122901296;
  Quad2DWeight{16+1}(4+1) = 0.083420593478774;

  Quad2DPointX{16+1}(5+1) = -0.173061122901296;
  Quad2DPointY{16+1}(5+1) = -0.653877754197410;
  Quad2DWeight{16+1}(5+1) = 0.083420593478774;

  Quad2DPointX{16+1}(6+1) = -0.653877754197410;
  Quad2DPointY{16+1}(6+1) = -0.173061122901296;
  Quad2DWeight{16+1}(6+1) = 0.083420593478774;

  Quad2DPointX{16+1}(7+1) = -0.059082801866018;
  Quad2DPointY{16+1}(7+1) = -0.059082801866018;
  Quad2DWeight{16+1}(7+1) = 0.053782968500128;

  Quad2DPointX{16+1}(8+1) = -0.059082801866018;
  Quad2DPointY{16+1}(8+1) = -0.881834396267966;
  Quad2DWeight{16+1}(8+1) = 0.053782968500128;

  Quad2DPointX{16+1}(9+1) = -0.881834396267966;
  Quad2DPointY{16+1}(9+1) = -0.059082801866018;
  Quad2DWeight{16+1}(9+1) = 0.053782968500128;

  Quad2DPointX{16+1}(10+1) = -0.518892500060958;
  Quad2DPointY{16+1}(10+1) = -0.518892500060958;
  Quad2DWeight{16+1}(10+1) = 0.084265045523300;

  Quad2DPointX{16+1}(11+1) = -0.518892500060958;
  Quad2DPointY{16+1}(11+1) = 0.037785000121916;
  Quad2DWeight{16+1}(11+1) = 0.084265045523300;

  Quad2DPointX{16+1}(12+1) = 0.037785000121916;
  Quad2DPointY{16+1}(12+1) = -0.518892500060958;
  Quad2DWeight{16+1}(12+1) = 0.084265045523300;

  Quad2DPointX{16+1}(13+1) = -0.704068411554854;
  Quad2DPointY{16+1}(13+1) = -0.704068411554854;
  Quad2DWeight{16+1}(13+1) = 0.060000533685546;

  Quad2DPointX{16+1}(14+1) = -0.704068411554854;
  Quad2DPointY{16+1}(14+1) = 0.408136823109708;
  Quad2DWeight{16+1}(14+1) = 0.060000533685546;

  Quad2DPointX{16+1}(15+1) = 0.408136823109708;
  Quad2DPointY{16+1}(15+1) = -0.704068411554854;
  Quad2DWeight{16+1}(15+1) = 0.060000533685546;

  Quad2DPointX{16+1}(16+1) = -0.849069624685052;
  Quad2DPointY{16+1}(16+1) = -0.849069624685052;
  Quad2DWeight{16+1}(16+1) = 0.028400197850048;

  Quad2DPointX{16+1}(17+1) = -0.849069624685052;
  Quad2DPointY{16+1}(17+1) = 0.698139249370104;
  Quad2DWeight{16+1}(17+1) = 0.028400197850048;

  Quad2DPointX{16+1}(18+1) = 0.698139249370104;
  Quad2DPointY{16+1}(18+1) = -0.849069624685052;
  Quad2DWeight{16+1}(18+1) = 0.028400197850048;

  Quad2DPointX{16+1}(19+1) = -0.966807194753950;
  Quad2DPointY{16+1}(19+1) = -0.966807194753950;
  Quad2DWeight{16+1}(19+1) = 0.007164924702546;

  Quad2DPointX{16+1}(20+1) = -0.966807194753950;
  Quad2DPointY{16+1}(20+1) = 0.933614389507900;
  Quad2DWeight{16+1}(20+1) = 0.007164924702546;

  Quad2DPointX{16+1}(21+1) = 0.933614389507900;
  Quad2DPointY{16+1}(21+1) = -0.966807194753950;
  Quad2DWeight{16+1}(21+1) = 0.007164924702546;

  Quad2DPointX{16+1}(22+1) = -0.406888806840226;
  Quad2DPointY{16+1}(22+1) = 0.199737422349722;
  Quad2DWeight{16+1}(22+1) = 0.065546294921254;

  Quad2DPointX{16+1}(23+1) = 0.199737422349722;
  Quad2DPointY{16+1}(23+1) = -0.792848615509496;
  Quad2DWeight{16+1}(23+1) = 0.065546294921254;

  Quad2DPointX{16+1}(24+1) = -0.792848615509496;
  Quad2DPointY{16+1}(24+1) = -0.406888806840226;
  Quad2DWeight{16+1}(24+1) = 0.065546294921254;

  Quad2DPointX{16+1}(25+1) = -0.406888806840226;
  Quad2DPointY{16+1}(25+1) = -0.792848615509496;
  Quad2DWeight{16+1}(25+1) = 0.065546294921254;

  Quad2DPointX{16+1}(26+1) = 0.199737422349722;
  Quad2DPointY{16+1}(26+1) = -0.406888806840226;
  Quad2DWeight{16+1}(26+1) = 0.065546294921254;

  Quad2DPointX{16+1}(27+1) = -0.792848615509496;
  Quad2DPointY{16+1}(27+1) = 0.199737422349722;
  Quad2DWeight{16+1}(27+1) = 0.065546294921254;

  Quad2DPointX{16+1}(28+1) = -0.324553873193842;
  Quad2DPointY{16+1}(28+1) = 0.284387049883010;
  Quad2DWeight{16+1}(28+1) = 0.030596612496882;

  Quad2DPointX{16+1}(29+1) = 0.284387049883010;
  Quad2DPointY{16+1}(29+1) = -0.959833176689168;
  Quad2DWeight{16+1}(29+1) = 0.030596612496882;

  Quad2DPointX{16+1}(30+1) = -0.959833176689168;
  Quad2DPointY{16+1}(30+1) = -0.324553873193842;
  Quad2DWeight{16+1}(30+1) = 0.030596612496882;

  Quad2DPointX{16+1}(31+1) = -0.324553873193842;
  Quad2DPointY{16+1}(31+1) = -0.959833176689168;
  Quad2DWeight{16+1}(31+1) = 0.030596612496882;

  Quad2DPointX{16+1}(32+1) = 0.284387049883010;
  Quad2DPointY{16+1}(32+1) = -0.324553873193842;
  Quad2DWeight{16+1}(32+1) = 0.030596612496882;

  Quad2DPointX{16+1}(33+1) = -0.959833176689168;
  Quad2DPointY{16+1}(33+1) = 0.284387049883010;
  Quad2DWeight{16+1}(33+1) = 0.030596612496882;

  Quad2DPointX{16+1}(34+1) = -0.590503436714376;
  Quad2DPointY{16+1}(34+1) = 0.599185441942654;
  Quad2DWeight{16+1}(34+1) = 0.004772488385678;

  Quad2DPointX{16+1}(35+1) = 0.599185441942654;
  Quad2DPointY{16+1}(35+1) = -1.008682005228278;
  Quad2DWeight{16+1}(35+1) = 0.004772488385678;

  Quad2DPointX{16+1}(36+1) = -1.008682005228278;
  Quad2DPointY{16+1}(36+1) = -0.590503436714376;
  Quad2DWeight{16+1}(36+1) = 0.004772488385678;

  Quad2DPointX{16+1}(37+1) = -0.590503436714376;
  Quad2DPointY{16+1}(37+1) = -1.008682005228278;
  Quad2DWeight{16+1}(37+1) = 0.004772488385678;

  Quad2DPointX{16+1}(38+1) = 0.599185441942654;
  Quad2DPointY{16+1}(38+1) = -0.590503436714376;
  Quad2DWeight{16+1}(38+1) = 0.004772488385678;

  Quad2DPointX{16+1}(39+1) = -1.008682005228278;
  Quad2DPointY{16+1}(39+1) = 0.599185441942654;
  Quad2DWeight{16+1}(39+1) = 0.004772488385678;

  Quad2DPointX{16+1}(40+1) = -0.621283015738754;
  Quad2DPointY{16+1}(40+1) = 0.537399442802736;
  Quad2DWeight{16+1}(40+1) = 0.038169585511798;

  Quad2DPointX{16+1}(41+1) = 0.537399442802736;
  Quad2DPointY{16+1}(41+1) = -0.916116427063980;
  Quad2DWeight{16+1}(41+1) = 0.038169585511798;

  Quad2DPointX{16+1}(42+1) = -0.916116427063980;
  Quad2DPointY{16+1}(42+1) = -0.621283015738754;
  Quad2DWeight{16+1}(42+1) = 0.038169585511798;

  Quad2DPointX{16+1}(43+1) = -0.621283015738754;
  Quad2DPointY{16+1}(43+1) = -0.916116427063980;
  Quad2DWeight{16+1}(43+1) = 0.038169585511798;

  Quad2DPointX{16+1}(44+1) = 0.537399442802736;
  Quad2DPointY{16+1}(44+1) = -0.621283015738754;
  Quad2DWeight{16+1}(44+1) = 0.038169585511798;

  Quad2DPointX{16+1}(45+1) = -0.916116427063980;
  Quad2DPointY{16+1}(45+1) = 0.537399442802736;
  Quad2DWeight{16+1}(45+1) = 0.038169585511798;

  Quad2DPointX{16+1}(46+1) = -0.829432768634686;
  Quad2DPointY{16+1}(46+1) = 0.800798128173322;
  Quad2DWeight{16+1}(46+1) = 0.013700109093084;

  Quad2DPointX{16+1}(47+1) = 0.800798128173322;
  Quad2DPointY{16+1}(47+1) = -0.971365359538638;
  Quad2DWeight{16+1}(47+1) = 0.013700109093084;

  Quad2DPointX{16+1}(48+1) = -0.971365359538638;
  Quad2DPointY{16+1}(48+1) = -0.829432768634686;
  Quad2DWeight{16+1}(48+1) = 0.013700109093084;

  Quad2DPointX{16+1}(49+1) = -0.829432768634686;
  Quad2DPointY{16+1}(49+1) = -0.971365359538638;
  Quad2DWeight{16+1}(49+1) = 0.013700109093084;

  Quad2DPointX{16+1}(50+1) = 0.800798128173322;
  Quad2DPointY{16+1}(50+1) = -0.829432768634686;
  Quad2DWeight{16+1}(50+1) = 0.013700109093084;

  Quad2DPointX{16+1}(51+1) = -0.971365359538638;
  Quad2DPointY{16+1}(51+1) = 0.800798128173322;
  Quad2DWeight{16+1}(51+1) = 0.013700109093084;

  % 17. stupen
  Quad2DPointNum(17+1) = 61;
  Quad2DPointX{17+1} = zeros(Quad2DPointNum(17+1),1);
  Quad2DPointY{17+1} = zeros(Quad2DPointNum(17+1),1);
  Quad2DWeight{17+1} = zeros(Quad2DPointNum(17+1),1);

  Quad2DPointX{17+1}(0+1) = -0.333333333333333;
  Quad2DPointY{17+1}(0+1) = -0.333333333333333;
  Quad2DWeight{17+1}(0+1) = 0.066874398581606;

  Quad2DPointX{17+1}(1+1) = -0.005658918886452;
  Quad2DPointY{17+1}(1+1) = -0.005658918886452;
  Quad2DWeight{17+1}(1+1) = 0.010186830881014;

  Quad2DPointX{17+1}(2+1) = -0.005658918886452;
  Quad2DPointY{17+1}(2+1) = -0.988682162227096;
  Quad2DWeight{17+1}(2+1) = 0.010186830881014;

  Quad2DPointX{17+1}(3+1) = -0.988682162227096;
  Quad2DPointY{17+1}(3+1) = -0.005658918886452;
  Quad2DWeight{17+1}(3+1) = 0.010186830881014;

  Quad2DPointX{17+1}(4+1) = -0.035647354750750;
  Quad2DPointY{17+1}(4+1) = -0.035647354750750;
  Quad2DWeight{17+1}(4+1) = 0.029341729055276;

  Quad2DPointX{17+1}(5+1) = -0.035647354750750;
  Quad2DPointY{17+1}(5+1) = -0.928705290498498;
  Quad2DWeight{17+1}(5+1) = 0.029341729055276;

  Quad2DPointX{17+1}(6+1) = -0.928705290498498;
  Quad2DPointY{17+1}(6+1) = -0.035647354750750;
  Quad2DWeight{17+1}(6+1) = 0.029341729055276;

  Quad2DPointX{17+1}(7+1) = -0.099520061958436;
  Quad2DPointY{17+1}(7+1) = -0.099520061958436;
  Quad2DWeight{17+1}(7+1) = 0.048701756707344;

  Quad2DPointX{17+1}(8+1) = -0.099520061958436;
  Quad2DPointY{17+1}(8+1) = -0.800959876083126;
  Quad2DWeight{17+1}(8+1) = 0.048701756707344;

  Quad2DPointX{17+1}(9+1) = -0.800959876083126;
  Quad2DPointY{17+1}(9+1) = -0.099520061958436;
  Quad2DWeight{17+1}(9+1) = 0.048701756707344;

  Quad2DPointX{17+1}(10+1) = -0.199467521245206;
  Quad2DPointY{17+1}(10+1) = -0.199467521245206;
  Quad2DWeight{17+1}(10+1) = 0.062215101737938;

  Quad2DPointX{17+1}(11+1) = -0.199467521245206;
  Quad2DPointY{17+1}(11+1) = -0.601064957509588;
  Quad2DWeight{17+1}(11+1) = 0.062215101737938;

  Quad2DPointX{17+1}(12+1) = -0.601064957509588;
  Quad2DPointY{17+1}(12+1) = -0.199467521245206;
  Quad2DWeight{17+1}(12+1) = 0.062215101737938;

  Quad2DPointX{17+1}(13+1) = -0.495717464058094;
  Quad2DPointY{17+1}(13+1) = -0.495717464058094;
  Quad2DWeight{17+1}(13+1) = 0.062514222437240;

  Quad2DPointX{17+1}(14+1) = -0.495717464058094;
  Quad2DPointY{17+1}(14+1) = -0.008565071883810;
  Quad2DWeight{17+1}(14+1) = 0.062514222437240;

  Quad2DPointX{17+1}(15+1) = -0.008565071883810;
  Quad2DPointY{17+1}(15+1) = -0.495717464058094;
  Quad2DWeight{17+1}(15+1) = 0.062514222437240;

  Quad2DPointX{17+1}(16+1) = -0.675905990683078;
  Quad2DPointY{17+1}(16+1) = -0.675905990683078;
  Quad2DWeight{17+1}(16+1) = 0.049631308679330;

  Quad2DPointX{17+1}(17+1) = -0.675905990683078;
  Quad2DPointY{17+1}(17+1) = 0.351811981366154;
  Quad2DWeight{17+1}(17+1) = 0.049631308679330;

  Quad2DPointX{17+1}(18+1) = 0.351811981366154;
  Quad2DPointY{17+1}(18+1) = -0.675905990683078;
  Quad2DWeight{17+1}(18+1) = 0.049631308679330;

  Quad2DPointX{17+1}(19+1) = -0.848248235478508;
  Quad2DPointY{17+1}(19+1) = -0.848248235478508;
  Quad2DWeight{17+1}(19+1) = 0.028112146141114;

  Quad2DPointX{17+1}(20+1) = -0.848248235478508;
  Quad2DPointY{17+1}(20+1) = 0.696496470957016;
  Quad2DWeight{17+1}(20+1) = 0.028112146141114;

  Quad2DPointX{17+1}(21+1) = 0.696496470957016;
  Quad2DPointY{17+1}(21+1) = -0.848248235478508;
  Quad2DWeight{17+1}(21+1) = 0.028112146141114;

  Quad2DPointX{17+1}(22+1) = -0.968690546064356;
  Quad2DPointY{17+1}(22+1) = -0.968690546064356;
  Quad2DWeight{17+1}(22+1) = 0.006389352347558;

  Quad2DPointX{17+1}(23+1) = -0.968690546064356;
  Quad2DPointY{17+1}(23+1) = 0.937381092128712;
  Quad2DWeight{17+1}(23+1) = 0.006389352347558;

  Quad2DPointX{17+1}(24+1) = 0.937381092128712;
  Quad2DPointY{17+1}(24+1) = -0.968690546064356;
  Quad2DWeight{17+1}(24+1) = 0.006389352347558;

  Quad2DPointX{17+1}(25+1) = -0.331360265272684;
  Quad2DPointY{17+1}(25+1) = 0.310986407618846;
  Quad2DWeight{17+1}(25+1) = 0.016239310637986;

  Quad2DPointX{17+1}(26+1) = 0.310986407618846;
  Quad2DPointY{17+1}(26+1) = -0.979626142346162;
  Quad2DWeight{17+1}(26+1) = 0.016239310637986;

  Quad2DPointX{17+1}(27+1) = -0.979626142346162;
  Quad2DPointY{17+1}(27+1) = -0.331360265272684;
  Quad2DWeight{17+1}(27+1) = 0.016239310637986;

  Quad2DPointX{17+1}(28+1) = -0.331360265272684;
  Quad2DPointY{17+1}(28+1) = -0.979626142346162;
  Quad2DWeight{17+1}(28+1) = 0.016239310637986;

  Quad2DPointX{17+1}(29+1) = 0.310986407618846;
  Quad2DPointY{17+1}(29+1) = -0.331360265272684;
  Quad2DWeight{17+1}(29+1) = 0.016239310637986;

  Quad2DPointX{17+1}(30+1) = -0.979626142346162;
  Quad2DPointY{17+1}(30+1) = 0.310986407618846;
  Quad2DWeight{17+1}(30+1) = 0.016239310637986;

  Quad2DPointX{17+1}(31+1) = -0.415556924406112;
  Quad2DPointY{17+1}(31+1) = 0.144675181064040;
  Quad2DWeight{17+1}(31+1) = 0.053611484566326;

  Quad2DPointX{17+1}(32+1) = 0.144675181064040;
  Quad2DPointY{17+1}(32+1) = -0.729118256657928;
  Quad2DWeight{17+1}(32+1) = 0.053611484566326;

  Quad2DPointX{17+1}(33+1) = -0.729118256657928;
  Quad2DPointY{17+1}(33+1) = -0.415556924406112;
  Quad2DWeight{17+1}(33+1) = 0.053611484566326;

  Quad2DPointX{17+1}(34+1) = -0.415556924406112;
  Quad2DPointY{17+1}(34+1) = -0.729118256657928;
  Quad2DWeight{17+1}(34+1) = 0.053611484566326;

  Quad2DPointX{17+1}(35+1) = 0.144675181064040;
  Quad2DPointY{17+1}(35+1) = -0.415556924406112;
  Quad2DWeight{17+1}(35+1) = 0.053611484566326;

  Quad2DPointX{17+1}(36+1) = -0.729118256657928;
  Quad2DPointY{17+1}(36+1) = 0.144675181064040;
  Quad2DWeight{17+1}(36+1) = 0.053611484566326;

  Quad2DPointX{17+1}(37+1) = -0.360850229153620;
  Quad2DPointY{17+1}(37+1) = 0.252002380572456;
  Quad2DWeight{17+1}(37+1) = 0.036919986421644;

  Quad2DPointX{17+1}(38+1) = 0.252002380572456;
  Quad2DPointY{17+1}(38+1) = -0.891152151418834;
  Quad2DWeight{17+1}(38+1) = 0.036919986421644;

  Quad2DPointX{17+1}(39+1) = -0.891152151418834;
  Quad2DPointY{17+1}(39+1) = -0.360850229153620;
  Quad2DWeight{17+1}(39+1) = 0.036919986421644;

  Quad2DPointX{17+1}(40+1) = -0.360850229153620;
  Quad2DPointY{17+1}(40+1) = -0.891152151418834;
  Quad2DWeight{17+1}(40+1) = 0.036919986421644;

  Quad2DPointX{17+1}(41+1) = 0.252002380572456;
  Quad2DPointY{17+1}(41+1) = -0.360850229153620;
  Quad2DWeight{17+1}(41+1) = 0.036919986421644;

  Quad2DPointX{17+1}(42+1) = -0.891152151418834;
  Quad2DPointY{17+1}(42+1) = 0.252002380572456;
  Quad2DWeight{17+1}(42+1) = 0.036919986421644;

  Quad2DPointX{17+1}(43+1) = -0.618591551615416;
  Quad2DPointY{17+1}(43+1) = 0.592854429948142;
  Quad2DWeight{17+1}(43+1) = 0.016953737068656;

  Quad2DPointX{17+1}(44+1) = 0.592854429948142;
  Quad2DPointY{17+1}(44+1) = -0.974262878332726;
  Quad2DWeight{17+1}(44+1) = 0.016953737068656;

  Quad2DPointX{17+1}(45+1) = -0.974262878332726;
  Quad2DPointY{17+1}(45+1) = -0.618591551615416;
  Quad2DWeight{17+1}(45+1) = 0.016953737068656;

  Quad2DPointX{17+1}(46+1) = -0.618591551615416;
  Quad2DPointY{17+1}(46+1) = -0.974262878332726;
  Quad2DWeight{17+1}(46+1) = 0.016953737068656;

  Quad2DPointX{17+1}(47+1) = 0.592854429948142;
  Quad2DPointY{17+1}(47+1) = -0.618591551615416;
  Quad2DWeight{17+1}(47+1) = 0.016953737068656;

  Quad2DPointX{17+1}(48+1) = -0.974262878332726;
  Quad2DPointY{17+1}(48+1) = 0.592854429948142;
  Quad2DWeight{17+1}(48+1) = 0.016953737068656;

  Quad2DPointX{17+1}(49+1) = -0.639033576702508;
  Quad2DPointY{17+1}(49+1) = 0.504702011875458;
  Quad2DWeight{17+1}(49+1) = 0.036585593540050;

  Quad2DPointX{17+1}(50+1) = 0.504702011875458;
  Quad2DPointY{17+1}(50+1) = -0.865668435172952;
  Quad2DWeight{17+1}(50+1) = 0.036585593540050;

  Quad2DPointX{17+1}(51+1) = -0.865668435172952;
  Quad2DPointY{17+1}(51+1) = -0.639033576702508;
  Quad2DWeight{17+1}(51+1) = 0.036585593540050;

  Quad2DPointX{17+1}(52+1) = -0.639033576702508;
  Quad2DPointY{17+1}(52+1) = -0.865668435172952;
  Quad2DWeight{17+1}(52+1) = 0.036585593540050;

  Quad2DPointX{17+1}(53+1) = 0.504702011875458;
  Quad2DPointY{17+1}(53+1) = -0.639033576702508;
  Quad2DWeight{17+1}(53+1) = 0.036585593540050;

  Quad2DPointX{17+1}(54+1) = -0.865668435172952;
  Quad2DPointY{17+1}(54+1) = 0.504702011875458;
  Quad2DWeight{17+1}(54+1) = 0.036585593540050;

  Quad2DPointX{17+1}(55+1) = -0.838577372640872;
  Quad2DPointY{17+1}(55+1) = 0.809251008191216;
  Quad2DWeight{17+1}(55+1) = 0.013331264008330;

  Quad2DPointX{17+1}(56+1) = 0.809251008191216;
  Quad2DPointY{17+1}(56+1) = -0.970673635550344;
  Quad2DWeight{17+1}(56+1) = 0.013331264008330;

  Quad2DPointX{17+1}(57+1) = -0.970673635550344;
  Quad2DPointY{17+1}(57+1) = -0.838577372640872;
  Quad2DWeight{17+1}(57+1) = 0.013331264008330;

  Quad2DPointX{17+1}(58+1) = -0.838577372640872;
  Quad2DPointY{17+1}(58+1) = -0.970673635550344;
  Quad2DWeight{17+1}(58+1) = 0.013331264008330;

  Quad2DPointX{17+1}(59+1) = 0.809251008191216;
  Quad2DPointY{17+1}(59+1) = -0.838577372640872;
  Quad2DWeight{17+1}(59+1) = 0.013331264008330;

  Quad2DPointX{17+1}(60+1) = -0.970673635550344;
  Quad2DPointY{17+1}(60+1) = 0.809251008191216;
  Quad2DWeight{17+1}(60+1) = 0.013331264008330;

  % 18. stupen
  Quad2DPointNum(18+1) = 70;
  Quad2DPointX{18+1} = zeros(Quad2DPointNum(18+1),1);
  Quad2DPointY{18+1} = zeros(Quad2DPointNum(18+1),1);
  Quad2DWeight{18+1} = zeros(Quad2DPointNum(18+1),1);

  Quad2DPointX{18+1}(0+1) = -0.333333333333333;
  Quad2DPointY{18+1}(0+1) = -0.333333333333333;
  Quad2DWeight{18+1}(0+1) = 0.061619879875294;

  Quad2DPointX{18+1}(1+1) = -0.013310382738158;
  Quad2DPointY{18+1}(1+1) = -0.013310382738158;
  Quad2DWeight{18+1}(1+1) = 0.018144873358808;

  Quad2DPointX{18+1}(2+1) = -0.013310382738158;
  Quad2DPointY{18+1}(2+1) = -0.973379234523686;
  Quad2DWeight{18+1}(2+1) = 0.018144873358808;

  Quad2DPointX{18+1}(3+1) = -0.973379234523686;
  Quad2DPointY{18+1}(3+1) = -0.013310382738158;
  Quad2DWeight{18+1}(3+1) = 0.018144873358808;

  Quad2DPointX{18+1}(4+1) = -0.061578811516086;
  Quad2DPointY{18+1}(4+1) = -0.061578811516086;
  Quad2DWeight{18+1}(4+1) = 0.037522633879188;

  Quad2DPointX{18+1}(5+1) = -0.061578811516086;
  Quad2DPointY{18+1}(5+1) = -0.876842376967828;
  Quad2DWeight{18+1}(5+1) = 0.037522633879188;

  Quad2DPointX{18+1}(6+1) = -0.876842376967828;
  Quad2DPointY{18+1}(6+1) = -0.061578811516086;
  Quad2DWeight{18+1}(6+1) = 0.037522633879188;

  Quad2DPointX{18+1}(7+1) = -0.127437208225988;
  Quad2DPointY{18+1}(7+1) = -0.127437208225988;
  Quad2DWeight{18+1}(7+1) = 0.038882195970954;

  Quad2DPointX{18+1}(8+1) = -0.127437208225988;
  Quad2DPointY{18+1}(8+1) = -0.745125583548022;
  Quad2DWeight{18+1}(8+1) = 0.038882195970954;

  Quad2DPointX{18+1}(9+1) = -0.745125583548022;
  Quad2DPointY{18+1}(9+1) = -0.127437208225988;
  Quad2DWeight{18+1}(9+1) = 0.038882195970954;

  Quad2DPointX{18+1}(10+1) = -0.210307658653168;
  Quad2DPointY{18+1}(10+1) = -0.210307658653168;
  Quad2DWeight{18+1}(10+1) = 0.055507897221620;

  Quad2DPointX{18+1}(11+1) = -0.210307658653168;
  Quad2DPointY{18+1}(11+1) = -0.579384682693664;
  Quad2DWeight{18+1}(11+1) = 0.055507897221620;

  Quad2DPointX{18+1}(12+1) = -0.579384682693664;
  Quad2DPointY{18+1}(12+1) = -0.210307658653168;
  Quad2DWeight{18+1}(12+1) = 0.055507897221620;

  Quad2DPointX{18+1}(13+1) = -0.500410862393686;
  Quad2DPointY{18+1}(13+1) = -0.500410862393686;
  Quad2DWeight{18+1}(13+1) = 0.064512450702914;

  Quad2DPointX{18+1}(14+1) = -0.500410862393686;
  Quad2DPointY{18+1}(14+1) = 0.000821724787372;
  Quad2DWeight{18+1}(14+1) = 0.064512450702914;

  Quad2DPointX{18+1}(15+1) = 0.000821724787372;
  Quad2DPointY{18+1}(15+1) = -0.500410862393686;
  Quad2DWeight{18+1}(15+1) = 0.064512450702914;

  Quad2DPointX{18+1}(16+1) = -0.677135612512314;
  Quad2DPointY{18+1}(16+1) = -0.677135612512314;
  Quad2DWeight{18+1}(16+1) = 0.050148065233844;

  Quad2DPointX{18+1}(17+1) = -0.677135612512314;
  Quad2DPointY{18+1}(17+1) = 0.354271225024630;
  Quad2DWeight{18+1}(17+1) = 0.050148065233844;

  Quad2DPointX{18+1}(18+1) = 0.354271225024630;
  Quad2DPointY{18+1}(18+1) = -0.677135612512314;
  Quad2DWeight{18+1}(18+1) = 0.050148065233844;

  Quad2DPointX{18+1}(19+1) = -0.846803545029258;
  Quad2DPointY{18+1}(19+1) = -0.846803545029258;
  Quad2DWeight{18+1}(19+1) = 0.030543855943664;

  Quad2DPointX{18+1}(20+1) = -0.846803545029258;
  Quad2DPointY{18+1}(20+1) = 0.693607090058514;
  Quad2DWeight{18+1}(20+1) = 0.030543855943664;

  Quad2DPointX{18+1}(21+1) = 0.693607090058514;
  Quad2DPointY{18+1}(21+1) = -0.846803545029258;
  Quad2DWeight{18+1}(21+1) = 0.030543855943664;

  Quad2DPointX{18+1}(22+1) = -0.951495121293100;
  Quad2DPointY{18+1}(22+1) = -0.951495121293100;
  Quad2DWeight{18+1}(22+1) = 0.013587844045926;

  Quad2DPointX{18+1}(23+1) = -0.951495121293100;
  Quad2DPointY{18+1}(23+1) = 0.902990242586200;
  Quad2DWeight{18+1}(23+1) = 0.013587844045926;

  Quad2DPointX{18+1}(24+1) = 0.902990242586200;
  Quad2DPointY{18+1}(24+1) = -0.951495121293100;
  Quad2DWeight{18+1}(24+1) = 0.013587844045926;

  Quad2DPointX{18+1}(25+1) = -0.913707265566070;
  Quad2DPointY{18+1}(25+1) = -0.913707265566070;
  Quad2DWeight{18+1}(25+1) = -0.004446197459840;

  Quad2DPointX{18+1}(26+1) = -0.913707265566070;
  Quad2DPointY{18+1}(26+1) = 0.827414531132142;
  Quad2DWeight{18+1}(26+1) = -0.004446197459840;

  Quad2DPointX{18+1}(27+1) = 0.827414531132142;
  Quad2DPointY{18+1}(27+1) = -0.913707265566070;
  Quad2DWeight{18+1}(27+1) = -0.004446197459840;

  Quad2DPointX{18+1}(28+1) = -0.282177010118112;
  Quad2DPointY{18+1}(28+1) = 0.265315937713272;
  Quad2DWeight{18+1}(28+1) = 0.012663828152812;

  Quad2DPointX{18+1}(29+1) = 0.265315937713272;
  Quad2DPointY{18+1}(29+1) = -0.983138927595160;
  Quad2DWeight{18+1}(29+1) = 0.012663828152812;

  Quad2DPointX{18+1}(30+1) = -0.983138927595160;
  Quad2DPointY{18+1}(30+1) = -0.282177010118112;
  Quad2DWeight{18+1}(30+1) = 0.012663828152812;

  Quad2DPointX{18+1}(31+1) = -0.282177010118112;
  Quad2DPointY{18+1}(31+1) = -0.983138927595160;
  Quad2DWeight{18+1}(31+1) = 0.012663828152812;

  Quad2DPointX{18+1}(32+1) = 0.265315937713272;
  Quad2DPointY{18+1}(32+1) = -0.282177010118112;
  Quad2DWeight{18+1}(32+1) = 0.012663828152812;

  Quad2DPointX{18+1}(33+1) = -0.983138927595160;
  Quad2DPointY{18+1}(33+1) = 0.265315937713272;
  Quad2DWeight{18+1}(33+1) = 0.012663828152812;

  Quad2DPointX{18+1}(34+1) = -0.411195046496086;
  Quad2DPointY{18+1}(34+1) = 0.148821943021710;
  Quad2DWeight{18+1}(34+1) = 0.054515076098276;

  Quad2DPointX{18+1}(35+1) = 0.148821943021710;
  Quad2DPointY{18+1}(35+1) = -0.737626896525624;
  Quad2DWeight{18+1}(35+1) = 0.054515076098276;

  Quad2DPointX{18+1}(36+1) = -0.737626896525624;
  Quad2DPointY{18+1}(36+1) = -0.411195046496086;
  Quad2DWeight{18+1}(36+1) = 0.054515076098276;

  Quad2DPointX{18+1}(37+1) = -0.411195046496086;
  Quad2DPointY{18+1}(37+1) = -0.737626896525624;
  Quad2DWeight{18+1}(37+1) = 0.054515076098276;

  Quad2DPointX{18+1}(38+1) = 0.148821943021710;
  Quad2DPointY{18+1}(38+1) = -0.411195046496086;
  Quad2DWeight{18+1}(38+1) = 0.054515076098276;

  Quad2DPointX{18+1}(39+1) = -0.737626896525624;
  Quad2DPointY{18+1}(39+1) = 0.148821943021710;
  Quad2DWeight{18+1}(39+1) = 0.054515076098276;

  Quad2DPointX{18+1}(40+1) = -0.349964396716372;
  Quad2DPointY{18+1}(40+1) = 0.249558093585024;
  Quad2DWeight{18+1}(40+1) = 0.035353571298930;

  Quad2DPointX{18+1}(41+1) = 0.249558093585024;
  Quad2DPointY{18+1}(41+1) = -0.899593696868650;
  Quad2DWeight{18+1}(41+1) = 0.035353571298930;

  Quad2DPointX{18+1}(42+1) = -0.899593696868650;
  Quad2DPointY{18+1}(42+1) = -0.349964396716372;
  Quad2DWeight{18+1}(42+1) = 0.035353571298930;

  Quad2DPointX{18+1}(43+1) = -0.349964396716372;
  Quad2DPointY{18+1}(43+1) = -0.899593696868650;
  Quad2DWeight{18+1}(43+1) = 0.035353571298930;

  Quad2DPointX{18+1}(44+1) = 0.249558093585024;
  Quad2DPointY{18+1}(44+1) = -0.349964396716372;
  Quad2DWeight{18+1}(44+1) = 0.035353571298930;

  Quad2DPointX{18+1}(45+1) = -0.899593696868650;
  Quad2DPointY{18+1}(45+1) = 0.249558093585024;
  Quad2DWeight{18+1}(45+1) = 0.035353571298930;

  Quad2DPointX{18+1}(46+1) = -0.630524880667908;
  Quad2DPointY{18+1}(46+1) = 0.497866353046074;
  Quad2DWeight{18+1}(46+1) = 0.036758969276140;

  Quad2DPointX{18+1}(47+1) = 0.497866353046074;
  Quad2DPointY{18+1}(47+1) = -0.867341472378168;
  Quad2DWeight{18+1}(47+1) = 0.036758969276140;

  Quad2DPointX{18+1}(48+1) = -0.867341472378168;
  Quad2DPointY{18+1}(48+1) = -0.630524880667908;
  Quad2DWeight{18+1}(48+1) = 0.036758969276140;

  Quad2DPointX{18+1}(49+1) = -0.630524880667908;
  Quad2DPointY{18+1}(49+1) = -0.867341472378168;
  Quad2DWeight{18+1}(49+1) = 0.036758969276140;

  Quad2DPointX{18+1}(50+1) = 0.497866353046074;
  Quad2DPointY{18+1}(50+1) = -0.630524880667908;
  Quad2DWeight{18+1}(50+1) = 0.036758969276140;

  Quad2DPointX{18+1}(51+1) = -0.867341472378168;
  Quad2DPointY{18+1}(51+1) = 0.497866353046074;
  Quad2DWeight{18+1}(51+1) = 0.036758969276140;

  Quad2DPointX{18+1}(52+1) = -0.562406399973358;
  Quad2DPointY{18+1}(52+1) = 0.538414010840886;
  Quad2DWeight{18+1}(52+1) = 0.016209465616384;

  Quad2DPointX{18+1}(53+1) = 0.538414010840886;
  Quad2DPointY{18+1}(53+1) = -0.976007610867528;
  Quad2DWeight{18+1}(53+1) = 0.016209465616384;

  Quad2DPointX{18+1}(54+1) = -0.976007610867528;
  Quad2DPointY{18+1}(54+1) = -0.562406399973358;
  Quad2DWeight{18+1}(54+1) = 0.016209465616384;

  Quad2DPointX{18+1}(55+1) = -0.562406399973358;
  Quad2DPointY{18+1}(55+1) = -0.976007610867528;
  Quad2DWeight{18+1}(55+1) = 0.016209465616384;

  Quad2DPointX{18+1}(56+1) = 0.538414010840886;
  Quad2DPointY{18+1}(56+1) = -0.562406399973358;
  Quad2DWeight{18+1}(56+1) = 0.016209465616384;

  Quad2DPointX{18+1}(57+1) = -0.976007610867528;
  Quad2DPointY{18+1}(57+1) = 0.538414010840886;
  Quad2DWeight{18+1}(57+1) = 0.016209465616384;

  Quad2DPointX{18+1}(58+1) = -0.797640805727184;
  Quad2DPointY{18+1}(58+1) = 0.767924604546934;
  Quad2DWeight{18+1}(58+1) = 0.015268258141450;

  Quad2DPointX{18+1}(59+1) = 0.767924604546934;
  Quad2DPointY{18+1}(59+1) = -0.970283798819750;
  Quad2DWeight{18+1}(59+1) = 0.015268258141450;

  Quad2DPointX{18+1}(60+1) = -0.970283798819750;
  Quad2DPointY{18+1}(60+1) = -0.797640805727184;
  Quad2DWeight{18+1}(60+1) = 0.015268258141450;

  Quad2DPointX{18+1}(61+1) = -0.797640805727184;
  Quad2DPointY{18+1}(61+1) = -0.970283798819750;
  Quad2DWeight{18+1}(61+1) = 0.015268258141450;

  Quad2DPointX{18+1}(62+1) = 0.767924604546934;
  Quad2DPointY{18+1}(62+1) = -0.797640805727184;
  Quad2DWeight{18+1}(62+1) = 0.015268258141450;

  Quad2DPointX{18+1}(63+1) = -0.970283798819750;
  Quad2DPointY{18+1}(63+1) = 0.767924604546934;
  Quad2DWeight{18+1}(63+1) = 0.015268258141450;

  Quad2DPointX{18+1}(64+1) = -0.958250489434828;
  Quad2DPointY{18+1}(64+1) = 1.028694520010726;
  Quad2DWeight{18+1}(64+1) = 0.000092375321588;

  Quad2DPointX{18+1}(65+1) = 1.028694520010726;
  Quad2DPointY{18+1}(65+1) = -1.070444030575898;
  Quad2DWeight{18+1}(65+1) = 0.000092375321588;

  Quad2DPointX{18+1}(66+1) = -1.070444030575898;
  Quad2DPointY{18+1}(66+1) = -0.958250489748281;
  Quad2DWeight{18+1}(66+1) = 0.000092375321588;

  Quad2DPointX{18+1}(67+1) = -0.958250489434828;
  Quad2DPointY{18+1}(67+1) = -1.070444030575898;
  Quad2DWeight{18+1}(67+1) = 0.000092375321588;

  Quad2DPointX{18+1}(68+1) = 1.028694520010726;
  Quad2DPointY{18+1}(68+1) = -0.958250489434828;
  Quad2DWeight{18+1}(68+1) = 0.000092375321588;

  Quad2DPointX{18+1}(69+1) = -1.070444030575898;
  Quad2DPointY{18+1}(69+1) = 1.028694520010726;
  Quad2DWeight{18+1}(69+1) = 0.000092375321588;

  % 19. stupen
  Quad2DPointNum(19+1) = 73;
  Quad2DPointX{19+1} = zeros(Quad2DPointNum(19+1),1);
  Quad2DPointY{19+1} = zeros(Quad2DPointNum(19+1),1);
  Quad2DWeight{19+1} = zeros(Quad2DPointNum(19+1),1);

  Quad2DPointX{19+1}(0+1) = -0.333333333333333; % -0.333333333333333
  Quad2DPointY{19+1}(0+1) = -0.333333333333333; % -0.333333333333333
  Quad2DWeight{19+1}(0+1) = 0.065812662777838; % 0.065812662777838

  Quad2DPointX{19+1}(1+1) = -0.020780025853988;% -0.020780025853988
  Quad2DPointY{19+1}(1+1) = -0.020780025853988;% -0.020780025853988
  Quad2DWeight{19+1}(1+1) = 0.020661463782544;% 0.020661463782544

  Quad2DPointX{19+1}(2+1) = -0.020780025853988;% -0.020780025853988
  Quad2DPointY{19+1}(2+1) = -0.958439948292026;% -0.958439948292026
  Quad2DWeight{19+1}(2+1) = 0.020661463782544;% 0.020661463782544

  Quad2DPointX{19+1}(3+1) = -0.958439948292026;% -0.958439948292026
  Quad2DPointY{19+1}(3+1) = -0.020780025853988;% -0.020780025853988
  Quad2DWeight{19+1}(3+1) = 0.020661463782544;% 0.020661463782544

  Quad2DPointX{19+1}(4+1) = -0.090926214604214;% -0.090926214604214
  Quad2DPointY{19+1}(4+1) = -0.090926214604214;% -0.090926214604214
  Quad2DWeight{19+1}(4+1) = 0.044774494526032;% 0.044774494526032

  Quad2DPointX{19+1}(5+1) = -0.090926214604214;% -0.090926214604214
  Quad2DPointY{19+1}(5+1) = -0.818147570791570;% -0.818147570791570
  Quad2DWeight{19+1}(5+1) = 0.044774494526032;% 0.044774494526032

  Quad2DPointX{19+1}(6+1) = -0.818147570791570;% -0.818147570791570
  Quad2DPointY{19+1}(6+1) = -0.090926214604214;% -0.090926214604214
  Quad2DWeight{19+1}(6+1) = 0.044774494526032;% 0.044774494526032

  Quad2DPointX{19+1}(7+1) = -0.197166638701138;% -0.197166638701138
  Quad2DPointY{19+1}(7+1) = -0.197166638701138;% -0.197166638701138
  Quad2DWeight{19+1}(7+1) = 0.060532251738936;% 0.060532251738936

  Quad2DPointX{19+1}(8+1) = -0.197166638701138;% -0.197166638701138
  Quad2DPointY{19+1}(8+1) = -0.605666722597724;% -0.605666722597724
  Quad2DWeight{19+1}(8+1) = 0.060532251738936;% 0.060532251738936

  Quad2DPointX{19+1}(9+1) = -0.605666722597724;% -0.605666722597724
  Quad2DPointY{19+1}(9+1) = -0.197166638701138;% -0.197166638701138
  Quad2DWeight{19+1}(9+1) = 0.060532251738936;% 0.060532251738936

  Quad2DPointX{19+1}(10+1) = -0.488896691193804;% -0.488896691193804
  Quad2DPointY{19+1}(10+1) = -0.488896691193804;% -0.488896691193804
  Quad2DWeight{19+1}(10+1) = 0.060981935604396;% 0.060981935604396

  Quad2DPointX{19+1}(11+1) = -0.488896691193804;% -0.488896691193804
  Quad2DPointY{19+1}(11+1) = -0.022206617612390;% -0.022206617612390
  Quad2DWeight{19+1}(11+1) = 0.060981935604396;% 0.060981935604396

  Quad2DPointX{19+1}(12+1) = -0.022206617612390;% -0.022206617612390
  Quad2DPointY{19+1}(12+1) = -0.488896691193804;% -0.488896691193804
  Quad2DWeight{19+1}(12+1) = 0.060981935604396;% 0.060981935604396

  Quad2DPointX{19+1}(13+1) = -0.645844115695740;% -0.645844115695740
  Quad2DPointY{19+1}(13+1) = -0.645844115695740;% -0.645844115695740
  Quad2DWeight{19+1}(13+1) = 0.048318425483282;% 0.048318425483282

  Quad2DPointX{19+1}(14+1) = -0.645844115695740;% -0.645844115695740
  Quad2DPointY{19+1}(14+1) = 0.291688231391482;% 0.291688231391482
  Quad2DWeight{19+1}(14+1) = 0.048318425483282;% 0.048318425483282

  Quad2DPointX{19+1}(15+1) = 0.291688231391482;% 0.291688231391482
  Quad2DPointY{19+1}(15+1) = -0.645844115695740;% -0.645844115695740
  Quad2DWeight{19+1}(15+1) = 0.048318425483282;% 0.048318425483282

  Quad2DPointX{19+1}(16+1) = -0.779877893544096;% -0.779877893544096
  Quad2DPointY{19+1}(16+1) = -0.779877893544096;% -0.779877893544096
  Quad2DWeight{19+1}(16+1) = 0.032101607173602;% 0.032101607173602

  Quad2DPointX{19+1}(17+1) = -0.779877893544096;% -0.779877893544096
  Quad2DPointY{19+1}(17+1) = 0.559755787088192;% 0.559755787088192
  Quad2DWeight{19+1}(17+1) = 0.032101607173602;% 0.032101607173602

  Quad2DPointX{19+1}(18+1) = 0.559755787088192;% 0.559755787088192
  Quad2DPointY{19+1}(18+1) = -0.779877893544096;% -0.779877893544096
  Quad2DWeight{19+1}(18+1) = 0.032101607173602;% 0.032101607173602

  Quad2DPointX{19+1}(19+1) = -0.888942751496320;% -0.888942751496320
  Quad2DPointY{19+1}(19+1) = -0.888942751496320;% -0.888942751496320
  Quad2DWeight{19+1}(19+1) = 0.016169160523568;% 0.016169160523568

  Quad2DPointX{19+1}(20+1) = -0.888942751496320;% -0.888942751496320
  Quad2DPointY{19+1}(20+1) = 0.777885502992642;% 0.777885502992642
  Quad2DWeight{19+1}(20+1) = 0.016169160523568;% 0.016169160523568

  Quad2DPointX{19+1}(21+1) = 0.777885502992642;% 0.777885502992642
  Quad2DPointY{19+1}(21+1) = -0.888942751496320;% -0.888942751496320
  Quad2DWeight{19+1}(21+1) = 0.016169160523568;% 0.016169160523568

  Quad2DPointX{19+1}(22+1) = -0.974756272445542;% -0.974756272445542
  Quad2DPointY{19+1}(22+1) = -0.974756272445542;% -0.974756272445542
  Quad2DWeight{19+1}(22+1) = 0.004158724054970;% 0.004158724054970

  Quad2DPointX{19+1}(23+1) = -0.974756272445542;% -0.974756272445542
  Quad2DPointY{19+1}(23+1) = 0.949512544891086;% 0.949512544891086
  Quad2DWeight{19+1}(23+1) = 0.004158724054970;% 0.004158724054970

  Quad2DPointX{19+1}(24+1) = 0.949512544891086;% 0.949512544891086
  Quad2DPointY{19+1}(24+1) = -0.974756272445542;% -0.974756272445542
  Quad2DWeight{19+1}(24+1) = 0.004158724054970;% 0.004158724054970

  Quad2DPointX{19+1}(25+1) = -0.208490425286114;% -0.208490425286114
  Quad2DPointY{19+1}(25+1) = 0.201267589589290;% 0.201267589589290
  Quad2DWeight{19+1}(25+1) = 0.007769753809962;% 0.007769753809962

  Quad2DPointX{19+1}(26+1) = 0.201267589589290;% 0.201267589589290
  Quad2DPointY{19+1}(26+1) = -0.992777164303176;% -0.992777164303176
  Quad2DWeight{19+1}(26+1) = 0.007769753809962;% 0.007769753809962

  Quad2DPointX{19+1}(27+1) = -0.992777164303176;% -0.992777164303176
  Quad2DPointY{19+1}(27+1) = -0.208490425286114;% -0.208490425286114
  Quad2DWeight{19+1}(27+1) = 0.007769753809962;% 0.007769753809962

  Quad2DPointX{19+1}(28+1) = -0.208490425286114;% -0.208490425286114
  Quad2DPointY{19+1}(28+1) = -0.992777164303176;% -0.992777164303176
  Quad2DWeight{19+1}(28+1) = 0.007769753809962;% 0.007769753809962

  Quad2DPointX{19+1}(29+1) = 0.201267589589290;% 0.201267589589290
  Quad2DPointY{19+1}(29+1) = -0.208490425286114;% -0.208490425286114
  Quad2DWeight{19+1}(29+1) = 0.007769753809962;% 0.007769753809962

  Quad2DPointX{19+1}(30+1) = -0.992777164303176;% -0.992777164303176
  Quad2DPointY{19+1}(30+1) = 0.201267589589286;% 0.201267589589286
  Quad2DWeight{19+1}(30+1) = 0.007769753809962;% 0.007769753809962

  Quad2DPointX{19+1}(31+1) = -0.384140032239128;% -0.384140032239128
  Quad2DPointY{19+1}(31+1) = 0.115206523177568;% 0.115206523177568
  Quad2DWeight{19+1}(31+1) = 0.051148321224044;% 0.051148321224044

  Quad2DPointX{19+1}(32+1) = 0.115206523177568;% 0.115206523177568
  Quad2DPointY{19+1}(32+1) = -0.731066490938440;% -0.731066490938440
  Quad2DWeight{19+1}(32+1) = 0.051148321224044;% 0.051148321224044

  Quad2DPointX{19+1}(33+1) = -0.731066490938440;% -0.731066490938440
  Quad2DPointY{19+1}(33+1) = -0.384140032239128;% -0.384140032239128
  Quad2DWeight{19+1}(33+1) = 0.051148321224044;% 0.051148321224044

  Quad2DPointX{19+1}(34+1) = -0.384140032239128;% -0.384140032239128
  Quad2DPointY{19+1}(34+1) = -0.731066490938440;% -0.731066490938440
  Quad2DWeight{19+1}(34+1) = 0.051148321224044;% 0.051148321224044

  Quad2DPointX{19+1}(35+1) = 0.115206523177568;% 0.115206523177568
  Quad2DPointY{19+1}(35+1) = -0.384140032239128;% -0.384140032239128
  Quad2DWeight{19+1}(35+1) = 0.051148321224044;% 0.051148321224044

  Quad2DPointX{19+1}(36+1) = -0.731066490938440;% -0.731066490938440
  Quad2DPointY{19+1}(36+1) = 0.115206523177568;% 0.115206523177568
  Quad2DWeight{19+1}(36+1) = 0.051148321224044;% 0.051148321224044

  Quad2DPointX{19+1}(37+1) = -0.470866103186960;% -0.470866103186960
  Quad2DPointY{19+1}(37+1) = 0.441974051634730;% 0.441974051634730
  Quad2DWeight{19+1}(37+1) = 0.017761807146676;% 0.017761807146676

  Quad2DPointX{19+1}(38+1) = 0.441974051634730;% 0.441974051634730
  Quad2DPointY{19+1}(38+1) = -0.971107948447770;% -0.971107948447770
  Quad2DWeight{19+1}(38+1) = 0.017761807146676;% 0.017761807146676

  Quad2DPointX{19+1}(39+1) = -0.971107948447770;% -0.971107948447770
  Quad2DPointY{19+1}(39+1) = -0.470866103186960;% -0.470866103186960
  Quad2DWeight{19+1}(39+1) = 0.017761807146676;% 0.017761807146676

  Quad2DPointX{19+1}(40+1) = -0.470866103186960;% -0.470866103186960
  Quad2DPointY{19+1}(40+1) = -0.971107948447770;% -0.971107948447770
  Quad2DWeight{19+1}(40+1) = 0.017761807146676;% 0.017761807146676

  Quad2DPointX{19+1}(41+1) = 0.441974051634730;% 0.441974051634730
  Quad2DPointY{19+1}(41+1) = -0.470866103186960;% -0.470866103186960
  Quad2DWeight{19+1}(41+1) = 0.017761807146676;% 0.017761807146676

  Quad2DPointX{19+1}(42+1) = -0.971107948447770;% -0.971107948447770
  Quad2DPointY{19+1}(42+1) = 0.441974051634730;% 0.441974051634730
  Quad2DWeight{19+1}(42+1) = 0.017761807146676;% 0.017761807146676

  Quad2DPointX{19+1}(43+1) = -0.282921295588098;% -0.282921295588098
  Quad2DPointY{19+1}(43+1) = 0.189054137911742;% 0.189054137911742
  Quad2DWeight{19+1}(43+1) = 0.032249093523462;% 0.032249093523462

  Quad2DPointX{19+1}(44+1) = 0.189054137911742;% 0.189054137911742
  Quad2DPointY{19+1}(44+1) = -0.906132842323644;% -0.906132842323644
  Quad2DWeight{19+1}(44+1) = 0.032249093523462;% 0.032249093523462

  Quad2DPointX{19+1}(45+1) = -0.906132842323644;% -0.906132842323644
  Quad2DPointY{19+1}(45+1) = -0.282921295588098;% -0.282921295588098
  Quad2DWeight{19+1}(45+1) = 0.032249093523462;% 0.032249093523462

  Quad2DPointX{19+1}(46+1) = -0.282921295588098;% -0.282921295588098
  Quad2DPointY{19+1}(46+1) = -0.906132842323644;% -0.906132842323644
  Quad2DWeight{19+1}(46+1) = 0.032249093523462;% 0.032249093523462

  Quad2DPointX{19+1}(47+1) = 0.189054137911742;% 0.189054137911742
  Quad2DPointY{19+1}(47+1) = -0.282921295588098;% -0.282921295588098
  Quad2DWeight{19+1}(47+1) = 0.032249093523462;% 0.032249093523462

  Quad2DPointX{19+1}(48+1) = -0.906132842323644;% -0.906132842323644
  Quad2DPointY{19+1}(48+1) = 0.189054137911742;% 0.189054137911742
  Quad2DWeight{19+1}(48+1) = 0.032249093523462;% 0.032249093523462

  Quad2DPointX{19+1}(49+1) = -0.684385188062810;% -0.684385188062810
  Quad2DPointY{19+1}(49+1) = 0.678662947361678;% 0.678662947361678
  Quad2DWeight{19+1}(49+1) = 0.004983883634982;% 0.004983883634982

  Quad2DPointX{19+1}(50+1) = 0.678662947361678;% 0.678662947361678
  Quad2DPointY{19+1}(50+1) = -0.994277759298866;% -0.994277759298866
  Quad2DWeight{19+1}(50+1) = 0.004983883634982;% 0.004983883634982

  Quad2DPointX{19+1}(51+1) = -0.994277759298866;% -0.994277759298866
  Quad2DPointY{19+1}(51+1) = -0.684385188062810;% -0.684385188062810
  Quad2DWeight{19+1}(51+1) = 0.004983883634982;% 0.004983883634982

  Quad2DPointX{19+1}(52+1) = -0.684385188062810;% -0.684385188062810
  Quad2DPointY{19+1}(52+1) = -0.994277759298866;% -0.994277759298866
  Quad2DWeight{19+1}(52+1) = 0.004983883634982;% 0.004983883634982

  Quad2DPointX{19+1}(53+1) = 0.678662947361678;% 0.678662947361678
  Quad2DPointY{19+1}(53+1) = -0.684385188062810;% -0.684385188062810
  Quad2DWeight{19+1}(53+1) = 0.004983883634982;% 0.004983883634982

  Quad2DPointX{19+1}(54+1) = -0.994277759298866;% -0.994277759298866
  Quad2DPointY{19+1}(54+1) = 0.678662947361678;% 0.678662947361678
  Quad2DWeight{19+1}(54+1) = 0.004983883634982;% 0.004983883634982

  Quad2DPointX{19+1}(55+1) = -0.849898806048178;% -0.849898806048178
  Quad2DPointY{19+1}(55+1) = 0.402175957852346;% 0.402175957852346
  Quad2DWeight{19+1}(55+1) = 0.036485680237902;% 0.036485680237902

  Quad2DPointX{19+1}(56+1) = 0.402175957852346;% 0.402175957852346
  Quad2DPointY{19+1}(56+1) = -0.552277151804168;% -0.552277151804168
  Quad2DWeight{19+1}(56+1) = 0.036485680237902;% 0.036485680237902

  Quad2DPointX{19+1}(57+1) = -0.552277151804168;% -0.552277151804168
  Quad2DPointY{19+1}(57+1) = -0.849898806048178;% -0.849898806048178
  Quad2DWeight{19+1}(57+1) = 0.036485680237902;% 0.036485680237902

  Quad2DPointX{19+1}(58+1) = -0.849898806048178;% -0.849898806048178
  Quad2DPointY{19+1}(58+1) = -0.552277151804168;% -0.552277151804168
  Quad2DWeight{19+1}(58+1) = 0.036485680237902;% 0.036485680237902

  Quad2DPointX{19+1}(59+1) = 0.402175957852346;% 0.402175957852346
  Quad2DPointY{19+1}(59+1) = -0.849898806048178;% -0.849898806048178
  Quad2DWeight{19+1}(59+1) = 0.036485680237902;% 0.036485680237902

  Quad2DPointX{19+1}(60+1) = -0.552277151804168;% -0.552277151804168
  Quad2DPointY{19+1}(60+1) = 0.402175957852346;% 0.402175957852346
  Quad2DWeight{19+1}(60+1) = 0.036485680237902;% 0.036485680237902

  Quad2DPointX{19+1}(61+1) = -0.715156797773234;% -0.715156797773234
  Quad2DPointY{19+1}(61+1) = 0.645862648139714;% 0.645862648139714
  Quad2DWeight{19+1}(61+1) = 0.020517127472398;% 0.020517127472398

  Quad2DPointX{19+1}(62+1) = 0.645862648139714;% 0.645862648139714
  Quad2DPointY{19+1}(62+1) = -0.930705850366480;% -0.930705850366480
  Quad2DWeight{19+1}(62+1) = 0.020517127472398;% 0.020517127472398

  Quad2DPointX{19+1}(63+1) = -0.930705850366480;% -0.930705850366480
  Quad2DPointY{19+1}(63+1) = -0.715156797773234;% -0.715156797773234
  Quad2DWeight{19+1}(63+1) = 0.020517127472398;% 0.020517127472398

  Quad2DPointX{19+1}(64+1) = -0.715156797773234;% -0.715156797773234
  Quad2DPointY{19+1}(64+1) = -0.930705850366480;% -0.930705850366480
  Quad2DWeight{19+1}(64+1) = 0.020517127472398;% 0.020517127472398

  Quad2DPointX{19+1}(65+1) = 0.645862648139714;% 0.645862648139714
  Quad2DPointY{19+1}(65+1) = -0.715156797773234;% -0.715156797773234
  Quad2DWeight{19+1}(65+1) = 0.020517127472398;% 0.020517127472398

  Quad2DPointX{19+1}(66+1) = -0.930705850366480;% -0.930705850366480
  Quad2DPointY{19+1}(66+1) = 0.645862648139714;% 0.645862648139714
  Quad2DWeight{19+1}(66+1) = 0.020517127472398;% 0.020517127472398

  Quad2DPointX{19+1}(67+1) = -0.869010743834124;% -0.869010743834124
  Quad2DPointY{19+1}(67+1) = 0.848688505241568;% 0.848688505241568
  Quad2DWeight{19+1}(67+1) = 0.0075998577106040;% 0.007599857710604

  Quad2DPointX{19+1}(68+1) = 0.848688505241568;% 0.848688505241568
  Quad2DPointY{19+1}(68+1) = -0.979677761407444;% -0.979677761407444
  Quad2DWeight{19+1}(68+1) = 0.0075998577106040;% 0.007599857710604

  Quad2DPointX{19+1}(69+1) = -0.979677761407444;% -0.979677761407444
  Quad2DPointY{19+1}(69+1) = -0.869010743834124;% -0.869010743834124
  Quad2DWeight{19+1}(69+1) = 0.0075998577106040;% 0.007599857710604

  Quad2DPointX{19+1}(70+1) = -0.869010743834124;% -0.869010743834124
  Quad2DPointY{19+1}(70+1) = -0.979677761407444;% -0.979677761407444
  Quad2DWeight{19+1}(70+1) = 0.0075998577106040;% 0.007599857710604

  Quad2DPointX{19+1}(71+1) = 0.848688505241568;% 0.848688505241568
  Quad2DPointY{19+1}(71+1) = -0.869010743834124;% -0.869010743834124
  Quad2DWeight{19+1}(71+1) = 0.0075998577106040;% 0.007599857710604

  Quad2DPointX{19+1}(72+1) = -0.979677761407444;% -0.979677761407444
  Quad2DPointY{19+1}(72+1) = 0.848688505241568;% 0.848688505241568
  Quad2DWeight{19+1}(72+1) = 0.0075998577106040;% 0.007599857710604

  % 20. stupen
  Quad2DPointNum(20+1) = 79;
  Quad2DPointX{20+1} = zeros(Quad2DPointNum(20+1),1);
  Quad2DPointY{20+1} = zeros(Quad2DPointNum(20+1),1);
  Quad2DWeight{20+1} = zeros(Quad2DPointNum(20+1),1);

  Quad2DPointX{20+1}(0+1) = -0.333333333333333;
  Quad2DPointY{20+1}(0+1) = -0.333333333333333;
  Quad2DWeight{20+1}(0+1) = 0.066114111083248;

  Quad2DPointX{20+1}(1+1) = 0.001900928704400;
  Quad2DPointY{20+1}(1+1) = 0.001900928704400;
  Quad2DWeight{20+1}(1+1) = 0.001734038371326;

  Quad2DPointX{20+1}(2+1) = 0.001900928704400;
  Quad2DPointY{20+1}(2+1) = -1.003801857408800;
  Quad2DWeight{20+1}(2+1) = 0.001734038371326;

  Quad2DPointX{20+1}(3+1) = -1.003801857408800;
  Quad2DPointY{20+1}(3+1) = 0.001900928704400;
  Quad2DWeight{20+1}(3+1) = 0.001734038371326;

  Quad2DPointX{20+1}(4+1) = -0.023574084130543;
  Quad2DPointY{20+1}(4+1) = -0.023574084130543;
  Quad2DWeight{20+1}(4+1) = 0.023320105432896;

  Quad2DPointX{20+1}(5+1) = -0.023574084130543;
  Quad2DPointY{20+1}(5+1) = -0.952851831738914;
  Quad2DWeight{20+1}(5+1) = 0.023320105432896;

  Quad2DPointX{20+1}(6+1) = -0.952851831738914;
  Quad2DPointY{20+1}(6+1) = -0.023574084130543;
  Quad2DWeight{20+1}(6+1) = 0.023320105432896;

  Quad2DPointX{20+1}(7+1) = -0.089726626099435;
  Quad2DPointY{20+1}(7+1) = -0.089726626099435;
  Quad2DWeight{20+1}(7+1) = 0.045753872712842;

  Quad2DPointX{20+1}(8+1) = -0.089726626099435;
  Quad2DPointY{20+1}(8+1) = -0.820546727801130;
  Quad2DWeight{20+1}(8+1) = 0.045753872712842;

  Quad2DPointX{20+1}(9+1) = -0.820546727801130;
  Quad2DPointY{20+1}(9+1) = -0.089726626099435;
  Quad2DWeight{20+1}(9+1) = 0.045753872712842;

  Quad2DPointX{20+1}(10+1) = -0.196007481363421;
  Quad2DPointY{20+1}(10+1) = -0.196007481363421;
  Quad2DWeight{20+1}(10+1) = 0.060897965347876;

  Quad2DPointX{20+1}(11+1) = -0.196007481363421;
  Quad2DPointY{20+1}(11+1) = -0.607985037273158;
  Quad2DWeight{20+1}(11+1) = 0.060897965347876;

  Quad2DPointX{20+1}(12+1) = -0.607985037273158;
  Quad2DPointY{20+1}(12+1) = -0.196007481363421;
  Quad2DWeight{20+1}(12+1) = 0.060897965347876;

  Quad2DPointX{20+1}(13+1) = -0.488214180481157;
  Quad2DPointY{20+1}(13+1) = -0.488214180481157;
  Quad2DWeight{20+1}(13+1) = 0.061249783450710;

  Quad2DPointX{20+1}(14+1) = -0.488214180481157;
  Quad2DPointY{20+1}(14+1) = -0.023571639037686;
  Quad2DWeight{20+1}(14+1) = 0.061249783450710;

  Quad2DPointX{20+1}(15+1) = -0.023571639037686;
  Quad2DPointY{20+1}(15+1) = -0.488214180481157;
  Quad2DWeight{20+1}(15+1) = 0.061249783450710;

  Quad2DPointX{20+1}(16+1) = -0.647023488009788;
  Quad2DPointY{20+1}(16+1) = -0.647023488009788;
  Quad2DWeight{20+1}(16+1) = 0.048736115353600;

  Quad2DPointX{20+1}(17+1) = -0.647023488009788;
  Quad2DPointY{20+1}(17+1) = 0.294046976019576;
  Quad2DWeight{20+1}(17+1) = 0.048736115353600;

  Quad2DPointX{20+1}(18+1) = 0.294046976019576;
  Quad2DPointY{20+1}(18+1) = -0.647023488009788;
  Quad2DWeight{20+1}(18+1) = 0.048736115353600;

  Quad2DPointX{20+1}(19+1) = -0.791658289326483;
  Quad2DPointY{20+1}(19+1) = -0.791658289326483;
  Quad2DWeight{20+1}(19+1) = 0.031994864064048;

  Quad2DPointX{20+1}(20+1) = -0.791658289326483;
  Quad2DPointY{20+1}(20+1) = 0.583316578652966;
  Quad2DWeight{20+1}(20+1) = 0.031994864064048;

  Quad2DPointX{20+1}(21+1) = 0.583316578652966;
  Quad2DPointY{20+1}(21+1) = -0.791658289326483;
  Quad2DWeight{20+1}(21+1) = 0.031994864064048;

  Quad2DPointX{20+1}(22+1) = -0.893862072318140;
  Quad2DPointY{20+1}(22+1) = -0.893862072318140;
  Quad2DWeight{20+1}(22+1) = 0.015396603631204;

  Quad2DPointX{20+1}(23+1) = -0.893862072318140;
  Quad2DPointY{20+1}(23+1) = 0.787724144636280;
  Quad2DWeight{20+1}(23+1) = 0.015396603631204;

  Quad2DPointX{20+1}(24+1) = 0.787724144636280;
  Quad2DPointY{20+1}(24+1) = -0.893862072318140;
  Quad2DWeight{20+1}(24+1) = 0.015396603631204;

  Quad2DPointX{20+1}(25+1) = -0.916762569607942;
  Quad2DPointY{20+1}(25+1) = -0.916762569607942;
  Quad2DWeight{20+1}(25+1) = -0.001264120994976;

  Quad2DPointX{20+1}(26+1) = -0.916762569607942;
  Quad2DPointY{20+1}(26+1) = 0.833525139215884;
  Quad2DWeight{20+1}(26+1) = -0.001264120994976;

  Quad2DPointX{20+1}(27+1) = 0.833525139215884;
  Quad2DPointY{20+1}(27+1) = -0.916762569607942;
  Quad2DWeight{20+1}(27+1) = -0.001264120994976;

  Quad2DPointX{20+1}(28+1) = -0.976836157186356;
  Quad2DPointY{20+1}(28+1) = -0.976836157186356;
  Quad2DWeight{20+1}(28+1) = 0.003502268602386;

  Quad2DPointX{20+1}(29+1) = -0.976836157186356;
  Quad2DPointY{20+1}(29+1) = 0.953672314372712;
  Quad2DWeight{20+1}(29+1) = 0.003502268602386;

  Quad2DPointX{20+1}(30+1) = 0.953672314372712;
  Quad2DPointY{20+1}(30+1) = -0.976836157186356;
  Quad2DWeight{20+1}(30+1) = 0.003502268602386;

  Quad2DPointX{20+1}(31+1) = -0.310288459541998;
  Quad2DPointY{20+1}(31+1) = 0.212805292212320;
  Quad2DWeight{20+1}(31+1) = 0.032931678379152;

  Quad2DPointX{20+1}(32+1) = 0.212805292212320;
  Quad2DPointY{20+1}(32+1) = -0.902516832670322;
  Quad2DWeight{20+1}(32+1) = 0.032931678379152;

  Quad2DPointX{20+1}(33+1) = -0.902516832670322;
  Quad2DPointY{20+1}(33+1) = -0.310288459541998;
  Quad2DWeight{20+1}(33+1) = 0.032931678379152;

  Quad2DPointX{20+1}(34+1) = -0.310288459541998;
  Quad2DPointY{20+1}(34+1) = -0.902516832670322;
  Quad2DWeight{20+1}(34+1) = 0.032931678379152;

  Quad2DPointX{20+1}(35+1) = 0.212805292212320;
  Quad2DPointY{20+1}(35+1) = -0.310288459541998;
  Quad2DWeight{20+1}(35+1) = 0.032931678379152;

  Quad2DPointX{20+1}(36+1) = -0.902516832670322;
  Quad2DPointY{20+1}(36+1) = 0.212805292212320;
  Quad2DWeight{20+1}(36+1) = 0.032931678379152;

  Quad2DPointX{20+1}(37+1) = -0.244313460810292;
  Quad2DPointY{20+1}(37+1) = 0.231685228913082;
  Quad2DWeight{20+1}(37+1) = 0.009678067080970;

  Quad2DPointX{20+1}(38+1) = 0.231685228913082;
  Quad2DPointY{20+1}(38+1) = -0.987371768102790;
  Quad2DWeight{20+1}(38+1) = 0.009678067080970;

  Quad2DPointX{20+1}(39+1) = -0.987371768102790;
  Quad2DPointY{20+1}(39+1) = -0.244313460810292;
  Quad2DWeight{20+1}(39+1) = 0.009678067080970;

  Quad2DPointX{20+1}(40+1) = -0.244313460810292;
  Quad2DPointY{20+1}(40+1) = -0.987371768102790;
  Quad2DWeight{20+1}(40+1) = 0.009678067080970;

  Quad2DPointX{20+1}(41+1) = 0.231685228913082;
  Quad2DPointY{20+1}(41+1) = -0.244313460810292;
  Quad2DWeight{20+1}(41+1) = 0.009678067080970;

  Quad2DPointX{20+1}(42+1) = -0.987371768102790;
  Quad2DPointY{20+1}(42+1) = 0.231685228913082;
  Quad2DWeight{20+1}(42+1) = 0.009678067080970;

  Quad2DPointX{20+1}(43+1) = -0.386729041875286;
  Quad2DPointY{20+1}(43+1) = 0.118096000780590;
  Quad2DWeight{20+1}(43+1) = 0.051609813069300;

  Quad2DPointX{20+1}(44+1) = 0.118096000780590;
  Quad2DPointY{20+1}(44+1) = -0.731366958905304;
  Quad2DWeight{20+1}(44+1) = 0.051609813069300;

  Quad2DPointX{20+1}(45+1) = -0.731366958905304;
  Quad2DPointY{20+1}(45+1) = -0.386729041875286;
  Quad2DWeight{20+1}(45+1) = 0.051609813069300;

  Quad2DPointX{20+1}(46+1) = -0.386729041875286;
  Quad2DPointY{20+1}(46+1) = -0.731366958905304;
  Quad2DWeight{20+1}(46+1) = 0.051609813069300;

  Quad2DPointX{20+1}(47+1) = 0.118096000780590;
  Quad2DPointY{20+1}(47+1) = -0.386729041875286;
  Quad2DWeight{20+1}(47+1) = 0.051609813069300;

  Quad2DPointX{20+1}(48+1) = -0.731366958905304;
  Quad2DPointY{20+1}(48+1) = 0.118096000780590;
  Quad2DWeight{20+1}(48+1) = 0.051609813069300;

  Quad2DPointX{20+1}(49+1) = -0.501161274450516;
  Quad2DPointY{20+1}(49+1) = 0.473213486525732;
  Quad2DWeight{20+1}(49+1) = 0.016942182108882;

  Quad2DPointX{20+1}(50+1) = 0.473213486525732;
  Quad2DPointY{20+1}(50+1) = -0.972052212075216;
  Quad2DWeight{20+1}(50+1) = 0.016942182108882;

  Quad2DPointX{20+1}(51+1) = -0.972052212075216;
  Quad2DPointY{20+1}(51+1) = -0.501161274450516;
  Quad2DWeight{20+1}(51+1) = 0.016942182108882;

  Quad2DPointX{20+1}(52+1) = -0.501161274450516;
  Quad2DPointY{20+1}(52+1) = -0.972052212075216;
  Quad2DWeight{20+1}(52+1) = 0.016942182108882;

  Quad2DPointX{20+1}(53+1) = 0.473213486525732;
  Quad2DPointY{20+1}(53+1) = -0.501161274450516;
  Quad2DWeight{20+1}(53+1) = 0.016942182108882;

  Quad2DPointX{20+1}(54+1) = -0.972052212075216;
  Quad2DPointY{20+1}(54+1) = 0.473213486525732;
  Quad2DWeight{20+1}(54+1) = 0.016942182108882;

  Quad2DPointX{20+1}(55+1) = -0.574448550394396;
  Quad2DPointY{20+1}(55+1) = 0.423350284574868;
  Quad2DWeight{20+1}(55+1) = 0.036709828212560;

  Quad2DPointX{20+1}(56+1) = 0.423350284574868;
  Quad2DPointY{20+1}(56+1) = -0.848901734180472;
  Quad2DWeight{20+1}(56+1) = 0.036709828212560;

  Quad2DPointX{20+1}(57+1) = -0.848901734180472;
  Quad2DPointY{20+1}(57+1) = -0.574448550394396;
  Quad2DWeight{20+1}(57+1) = 0.036709828212560;

  Quad2DPointX{20+1}(58+1) = -0.574448550394396;
  Quad2DPointY{20+1}(58+1) = -0.848901734180472;
  Quad2DWeight{20+1}(58+1) = 0.036709828212560;

  Quad2DPointX{20+1}(59+1) = 0.423350284574868;
  Quad2DPointY{20+1}(59+1) = -0.574448550394396;
  Quad2DWeight{20+1}(59+1) = 0.036709828212560;

  Quad2DPointX{20+1}(60+1) = -0.848901734180472;
  Quad2DPointY{20+1}(60+1) = 0.423350284574868;
  Quad2DWeight{20+1}(60+1) = 0.036709828212560;

  Quad2DPointX{20+1}(61+1) = -0.706069127893522;
  Quad2DPointY{20+1}(61+1) = 0.722805434309974;
  Quad2DWeight{20+1}(61+1) = 0.001408809355816;

  Quad2DPointX{20+1}(62+1) = 0.722805434309974;
  Quad2DPointY{20+1}(62+1) = -1.016736306416454;
  Quad2DWeight{20+1}(62+1) = 0.001408809355816;

  Quad2DPointX{20+1}(63+1) = -1.016736306416454;
  Quad2DPointY{20+1}(63+1) = -0.706069127893522;
  Quad2DWeight{20+1}(63+1) = 0.001408809355816;

  Quad2DPointX{20+1}(64+1) = -0.706069127893522;
  Quad2DPointY{20+1}(64+1) = -1.016736306416454;
  Quad2DWeight{20+1}(64+1) = 0.001408809355816;

  Quad2DPointX{20+1}(65+1) = 0.722805434309974;
  Quad2DPointY{20+1}(65+1) = -0.706069127893522;
  Quad2DWeight{20+1}(65+1) = 0.001408809355816;

  Quad2DPointX{20+1}(66+1) = -1.016736306416454;
  Quad2DPointY{20+1}(66+1) = 0.722805434309974;
  Quad2DWeight{20+1}(66+1) = 0.001408809355816;

  Quad2DPointX{20+1}(67+1) = -0.724546042342154;
  Quad2DPointY{20+1}(67+1) = 0.671173915824726;
  Quad2DWeight{20+1}(67+1) = 0.020225369854924;

  Quad2DPointX{20+1}(68+1) = 0.671173915824726;
  Quad2DPointY{20+1}(68+1) = -0.946627873482572;
  Quad2DWeight{20+1}(68+1) = 0.020225369854924;

  Quad2DPointX{20+1}(69+1) = -0.946627873482572;
  Quad2DPointY{20+1}(69+1) = -0.724546042342154;
  Quad2DWeight{20+1}(69+1) = 0.020225369854924;

  Quad2DPointX{20+1}(70+1) = -0.724546042342154;
  Quad2DPointY{20+1}(70+1) = -0.946627873482572;
  Quad2DWeight{20+1}(70+1) = 0.020225369854924;

  Quad2DPointX{20+1}(71+1) = 0.671173915824726;
  Quad2DPointY{20+1}(71+1) = -0.724546042342154;
  Quad2DWeight{20+1}(71+1) = 0.020225369854924;

  Quad2DPointX{20+1}(72+1) = -0.946627873482572;
  Quad2DPointY{20+1}(72+1) = 0.671173915824726;
  Quad2DWeight{20+1}(72+1) = 0.020225369854924;

  Quad2DPointX{20+1}(73+1) = -0.880607781701986;
  Quad2DPointY{20+1}(73+1) = 0.859512343113706;
  Quad2DWeight{20+1}(73+1) = 0.007147818771900;

  Quad2DPointX{20+1}(74+1) = 0.859512343113706;
  Quad2DPointY{20+1}(74+1) = -0.978904561411718;
  Quad2DWeight{20+1}(74+1) = 0.007147818771900;

  Quad2DPointX{20+1}(75+1) = -0.978904561411718;
  Quad2DPointY{20+1}(75+1) = -0.880607781701986;
  Quad2DWeight{20+1}(75+1) = 0.007147818771900;

  Quad2DPointX{20+1}(76+1) = -0.880607781701986;
  Quad2DPointY{20+1}(76+1) = -0.978904561411718;
  Quad2DWeight{20+1}(76+1) = 0.007147818771900;

  Quad2DPointX{20+1}(77+1) = 0.859512343113706;
  Quad2DPointY{20+1}(77+1) = -0.880607781701986;
  Quad2DWeight{20+1}(77+1) = 0.007147818771900;

  Quad2DPointX{20+1}(78+1) = -0.978904561411718;
  Quad2DPointY{20+1}(78+1) = 0.859512343113706;
  Quad2DWeight{20+1}(78+1) = 0.007147818771900;

  fprintf('done\n');
end % function initquad()

end % function trianglequad()